import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface CertificateSigningRequestConfig extends TerraformMetaArguments {
    /**
     * Automatically approve the CertificateSigningRequest.
     */
    readonly autoApprove?: boolean;
    /**
     * metadata block.
     */
    readonly metadata: CertificateSigningRequestMetadata[];
    /**
     * spec block.
     */
    readonly spec: CertificateSigningRequestSpec[];
    /**
     * timeouts block.
     */
    readonly timeouts?: CertificateSigningRequestTimeouts;
}
/**
 *
 */
export interface CertificateSigningRequestMetadata {
    /**
     * An unstructured key value map stored with the certificate signing request that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the certificate signing request.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the certificate signing request, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
}
/**
 *
 */
export interface CertificateSigningRequestSpec {
    /**
     * Base64-encoded PKCS#10 CSR data.
     */
    readonly request: string;
    /**
     * Requested signer for the request.
     *
     * It is a qualified name in the form: `scope-hostname.io/name`.If empty, it will be defaulted: 1. If it's a kubelet client certificate, it is assigned `kubernetes.io/kube-apiserver-client-kubelet`.2. If it's a kubelet serving certificate, it is assigned `kubernetes.io/kubelet-serving`.3. Otherwise, it is assigned `kubernetes.io/legacy-unknown`. Distribution of trust for signers happens out of band.You can select on this field using `spec.signerName`.
     */
    readonly signerName?: string;
    /**
     * allowedUsages specifies a set of usage contexts the key will be valid for.
     *
     * See: https://tools.ietf.org/html/rfc5280#section-4.2.1.3
     * https://tools.ietf.org/html/rfc5280#section-4.2.1.12
     */
    readonly usages?: string[];
}
/**
 *
 */
export interface CertificateSigningRequestTimeouts {
    /**
     *
     */
    readonly create?: string;
}
/**
 *
 */
export declare class CertificateSigningRequest extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: CertificateSigningRequestConfig);
    private _autoApprove?;
    /**
     *
     */
    get autoApprove(): boolean | undefined;
    /**
     *
     */
    set autoApprove(value: boolean | undefined);
    /**
     *
     */
    get certificate(): string;
    private _id?;
    /**
     *
     */
    get id(): string | undefined;
    /**
     *
     */
    set id(value: string | undefined);
    private _metadata;
    /**
     *
     */
    get metadata(): CertificateSigningRequestMetadata[];
    /**
     *
     */
    set metadata(value: CertificateSigningRequestMetadata[]);
    private _spec;
    /**
     *
     */
    get spec(): CertificateSigningRequestSpec[];
    /**
     *
     */
    set spec(value: CertificateSigningRequestSpec[]);
    private _timeouts?;
    /**
     *
     */
    get timeouts(): CertificateSigningRequestTimeouts | undefined;
    /**
     *
     */
    set timeouts(value: CertificateSigningRequestTimeouts | undefined);
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
