import { Construct } from 'constructs';
import { TerraformDataSource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface DataKubernetesConfigMapConfig extends TerraformMetaArguments {
    /**
     * metadata block.
     */
    readonly metadata: DataKubernetesConfigMapMetadata[];
}
/**
 *
 */
export interface DataKubernetesConfigMapMetadata {
    /**
     * An unstructured key value map stored with the config_map that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the config_map.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the config_map, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the config_map must be unique.
     */
    readonly namespace?: string;
}
/**
 *
 */
export declare class DataKubernetesConfigMap extends TerraformDataSource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: DataKubernetesConfigMapConfig);
    /**
     *
     */
    binaryData(key: string): string;
    /**
     *
     */
    data(key: string): string;
    private _id?;
    /**
     *
     */
    get id(): string | undefined;
    /**
     *
     */
    set id(value: string | undefined);
    private _metadata;
    /**
     *
     */
    get metadata(): DataKubernetesConfigMapMetadata[];
    /**
     *
     */
    set metadata(value: DataKubernetesConfigMapMetadata[]);
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
