import { Construct } from 'constructs';
import { TerraformDataSource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface DataKubernetesStorageClassConfig extends TerraformMetaArguments {
    /**
     * metadata block.
     */
    readonly metadata: DataKubernetesStorageClassMetadata[];
}
/**
 *
 */
export interface DataKubernetesStorageClassMetadata {
    /**
     * An unstructured key value map stored with the storage class that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the storage class.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the storage class, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
}
/**
 *
 */
export declare class DataKubernetesStorageClass extends TerraformDataSource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: DataKubernetesStorageClassConfig);
    /**
     *
     */
    get allowVolumeExpansion(): boolean;
    private _id?;
    /**
     *
     */
    get id(): string | undefined;
    /**
     *
     */
    set id(value: string | undefined);
    /**
     *
     */
    get mountOptions(): string[];
    /**
     *
     */
    parameters(key: string): string;
    /**
     *
     */
    get reclaimPolicy(): string;
    /**
     *
     */
    get storageProvisioner(): string;
    private _metadata;
    /**
     *
     */
    get metadata(): DataKubernetesStorageClassMetadata[];
    /**
     *
     */
    set metadata(value: DataKubernetesStorageClassMetadata[]);
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
