import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface PodConfig extends TerraformMetaArguments {
    /**
     * metadata block.
     */
    readonly metadata: PodMetadata[];
    /**
     * spec block.
     */
    readonly spec: PodSpec[];
    /**
     * timeouts block.
     */
    readonly timeouts?: PodTimeouts;
}
/**
 *
 */
export interface PodMetadata {
    /**
     * An unstructured key value map stored with the pod that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the pod.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the pod, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the pod must be unique.
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface PodSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions {
    /**
     * The label key that the selector applies to.
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to a set of values.
     *
     * Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
     */
    readonly operator?: string;
    /**
     * Values is an array of string values.
     *
     * If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface PodSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference {
    /**
     * match_expressions block.
     */
    readonly matchExpressions?: PodSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions[];
}
/**
 *
 */
export interface PodSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight is in the range 1-100.
     */
    readonly weight: number;
    /**
     * preference block.
     */
    readonly preference: PodSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference[];
}
/**
 *
 */
export interface PodSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions {
    /**
     * The label key that the selector applies to.
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to a set of values.
     *
     * Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
     */
    readonly operator?: string;
    /**
     * Values is an array of string values.
     *
     * If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface PodSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm {
    /**
     * match_expressions block.
     */
    readonly matchExpressions?: PodSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions[];
}
/**
 *
 */
export interface PodSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * node_selector_term block.
     */
    readonly nodeSelectorTerm?: PodSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm[];
}
/**
 *
 */
export interface PodSpecAffinityNodeAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: PodSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: PodSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
/**
 *
 */
export interface PodSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface PodSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     */
    readonly matchExpressions?: PodSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions[];
}
/**
 *
 */
export interface PodSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against);
     *
     * null or empty list means 'this pod's namespace'
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     */
    readonly labelSelector?: PodSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
}
/**
 *
 */
export interface PodSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
     */
    readonly weight: number;
    /**
     * pod_affinity_term block.
     */
    readonly podAffinityTerm: PodSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm[];
}
/**
 *
 */
export interface PodSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface PodSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     */
    readonly matchExpressions?: PodSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions[];
}
/**
 *
 */
export interface PodSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against);
     *
     * null or empty list means 'this pod's namespace'
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     */
    readonly labelSelector?: PodSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector[];
}
/**
 *
 */
export interface PodSpecAffinityPodAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: PodSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: PodSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
/**
 *
 */
export interface PodSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface PodSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     */
    readonly matchExpressions?: PodSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions[];
}
/**
 *
 */
export interface PodSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against);
     *
     * null or empty list means 'this pod's namespace'
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     */
    readonly labelSelector?: PodSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
}
/**
 *
 */
export interface PodSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
     */
    readonly weight: number;
    /**
     * pod_affinity_term block.
     */
    readonly podAffinityTerm: PodSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm[];
}
/**
 *
 */
export interface PodSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface PodSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     */
    readonly matchExpressions?: PodSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions[];
}
/**
 *
 */
export interface PodSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against);
     *
     * null or empty list means 'this pod's namespace'
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     */
    readonly labelSelector?: PodSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector[];
}
/**
 *
 */
export interface PodSpecAffinityPodAntiAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: PodSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: PodSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
/**
 *
 */
export interface PodSpecAffinity {
    /**
     * node_affinity block.
     */
    readonly nodeAffinity?: PodSpecAffinityNodeAffinity[];
    /**
     * pod_affinity block.
     */
    readonly podAffinity?: PodSpecAffinityPodAffinity[];
    /**
     * pod_anti_affinity block.
     */
    readonly podAntiAffinity?: PodSpecAffinityPodAntiAffinity[];
}
/**
 *
 */
export interface PodSpecContainerEnvValueFromConfigMapKeyRef {
    /**
     * The key to select.
     */
    readonly key?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Specify whether the ConfigMap or its key must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface PodSpecContainerEnvValueFromFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     */
    readonly fieldPath?: string;
}
/**
 *
 */
export interface PodSpecContainerEnvValueFromResourceFieldRef {
    /**
     *
     */
    readonly containerName?: string;
    /**
     * Resource to select.
     */
    readonly resource: string;
}
/**
 *
 */
export interface PodSpecContainerEnvValueFromSecretKeyRef {
    /**
     * The key of the secret to select from.
     *
     * Must be a valid secret key.
     */
    readonly key?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Specify whether the Secret or its key must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface PodSpecContainerEnvValueFrom {
    /**
     * config_map_key_ref block.
     */
    readonly configMapKeyRef?: PodSpecContainerEnvValueFromConfigMapKeyRef[];
    /**
     * field_ref block.
     */
    readonly fieldRef?: PodSpecContainerEnvValueFromFieldRef[];
    /**
     * resource_field_ref block.
     */
    readonly resourceFieldRef?: PodSpecContainerEnvValueFromResourceFieldRef[];
    /**
     * secret_key_ref block.
     */
    readonly secretKeyRef?: PodSpecContainerEnvValueFromSecretKeyRef[];
}
/**
 *
 */
export interface PodSpecContainerEnv {
    /**
     * Name of the environment variable.
     *
     * Must be a C_IDENTIFIER
     */
    readonly name: string;
    /**
     * Variable references $(VAR_NAME) are expanded using the previous defined environment variables in the container and any service environment variables.
     *
     * If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
     */
    readonly value?: string;
    /**
     * value_from block.
     */
    readonly valueFrom?: PodSpecContainerEnvValueFrom[];
}
/**
 *
 */
export interface PodSpecContainerEnvFromConfigMapRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name: string;
    /**
     * Specify whether the ConfigMap must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface PodSpecContainerEnvFromSecretRef {
    /**
     * Name of the referent.
     *
     * More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
     */
    readonly name: string;
    /**
     * Specify whether the Secret must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface PodSpecContainerEnvFrom {
    /**
     * An optional identifer to prepend to each key in the ConfigMap.
     *
     * Must be a C_IDENTIFIER.
     */
    readonly prefix?: string;
    /**
     * config_map_ref block.
     */
    readonly configMapRef?: PodSpecContainerEnvFromConfigMapRef[];
    /**
     * secret_ref block.
     */
    readonly secretRef?: PodSpecContainerEnvFromSecretRef[];
}
/**
 *
 */
export interface PodSpecContainerLifecyclePostStartExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface PodSpecContainerLifecyclePostStartHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface PodSpecContainerLifecyclePostStartHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: PodSpecContainerLifecyclePostStartHttpGetHttpHeader[];
}
/**
 *
 */
export interface PodSpecContainerLifecyclePostStartTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface PodSpecContainerLifecyclePostStart {
    /**
     * exec block.
     */
    readonly exec?: PodSpecContainerLifecyclePostStartExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: PodSpecContainerLifecyclePostStartHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: PodSpecContainerLifecyclePostStartTcpSocket[];
}
/**
 *
 */
export interface PodSpecContainerLifecyclePreStopExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface PodSpecContainerLifecyclePreStopHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface PodSpecContainerLifecyclePreStopHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: PodSpecContainerLifecyclePreStopHttpGetHttpHeader[];
}
/**
 *
 */
export interface PodSpecContainerLifecyclePreStopTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface PodSpecContainerLifecyclePreStop {
    /**
     * exec block.
     */
    readonly exec?: PodSpecContainerLifecyclePreStopExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: PodSpecContainerLifecyclePreStopHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: PodSpecContainerLifecyclePreStopTcpSocket[];
}
/**
 *
 */
export interface PodSpecContainerLifecycle {
    /**
     * post_start block.
     */
    readonly postStart?: PodSpecContainerLifecyclePostStart[];
    /**
     * pre_stop block.
     */
    readonly preStop?: PodSpecContainerLifecyclePreStop[];
}
/**
 *
 */
export interface PodSpecContainerLivenessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface PodSpecContainerLivenessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface PodSpecContainerLivenessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: PodSpecContainerLivenessProbeHttpGetHttpHeader[];
}
/**
 *
 */
export interface PodSpecContainerLivenessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface PodSpecContainerLivenessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     */
    readonly exec?: PodSpecContainerLivenessProbeExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: PodSpecContainerLivenessProbeHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: PodSpecContainerLivenessProbeTcpSocket[];
}
/**
 *
 */
export interface PodSpecContainerPort {
    /**
     * Number of port to expose on the pod's IP address.
     *
     * This must be a valid port number, 0 < x < 65536.
     */
    readonly containerPort: number;
    /**
     * What host IP to bind the external port to.
     */
    readonly hostIp?: string;
    /**
     * Number of port to expose on the host.
     *
     * If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
     */
    readonly hostPort?: number;
    /**
     * If specified, this must be an IANA_SVC_NAME and unique within the pod.
     *
     * Each named port in a pod must have a unique name. Name for the port that can be referred to by services
     */
    readonly name?: string;
    /**
     * Protocol for port.
     *
     * Must be UDP or TCP. Defaults to "TCP".
     */
    readonly protocol?: string;
}
/**
 *
 */
export interface PodSpecContainerReadinessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface PodSpecContainerReadinessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface PodSpecContainerReadinessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: PodSpecContainerReadinessProbeHttpGetHttpHeader[];
}
/**
 *
 */
export interface PodSpecContainerReadinessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface PodSpecContainerReadinessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     */
    readonly exec?: PodSpecContainerReadinessProbeExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: PodSpecContainerReadinessProbeHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: PodSpecContainerReadinessProbeTcpSocket[];
}
/**
 *
 */
export interface PodSpecContainerResourcesLimits {
    /**
     *
     */
    readonly cpu?: string;
    /**
     *
     */
    readonly memory?: string;
}
/**
 *
 */
export interface PodSpecContainerResourcesRequests {
    /**
     *
     */
    readonly cpu?: string;
    /**
     *
     */
    readonly memory?: string;
}
/**
 *
 */
export interface PodSpecContainerResources {
    /**
     * limits block.
     */
    readonly limits?: PodSpecContainerResourcesLimits[];
    /**
     * requests block.
     */
    readonly requests?: PodSpecContainerResourcesRequests[];
}
/**
 *
 */
export interface PodSpecContainerSecurityContextCapabilities {
    /**
     * Added capabilities.
     */
    readonly add?: string[];
    /**
     * Removed capabilities.
     */
    readonly drop?: string[];
}
/**
 *
 */
export interface PodSpecContainerSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     */
    readonly user?: string;
}
/**
 *
 */
export interface PodSpecContainerSecurityContext {
    /**
     * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process.
     *
     * This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN
     */
    readonly allowPrivilegeEscalation?: boolean;
    /**
     * Run container in privileged mode.
     *
     * Processes in privileged containers are essentially equivalent to root on the host. Defaults to false.
     */
    readonly privileged?: boolean;
    /**
     * Whether this container has a read-only root filesystem.
     *
     * Default is false.
     */
    readonly readOnlyRootFilesystem?: boolean;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     */
    readonly runAsGroup?: number;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     */
    readonly runAsNonRoot?: boolean;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     */
    readonly runAsUser?: number;
    /**
     * capabilities block.
     */
    readonly capabilities?: PodSpecContainerSecurityContextCapabilities[];
    /**
     * se_linux_options block.
     */
    readonly seLinuxOptions?: PodSpecContainerSecurityContextSeLinuxOptions[];
}
/**
 *
 */
export interface PodSpecContainerStartupProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface PodSpecContainerStartupProbeHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface PodSpecContainerStartupProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: PodSpecContainerStartupProbeHttpGetHttpHeader[];
}
/**
 *
 */
export interface PodSpecContainerStartupProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface PodSpecContainerStartupProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     */
    readonly exec?: PodSpecContainerStartupProbeExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: PodSpecContainerStartupProbeHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: PodSpecContainerStartupProbeTcpSocket[];
}
/**
 *
 */
export interface PodSpecContainerVolumeMount {
    /**
     * Path within the container at which the volume should be mounted.
     *
     * Must not contain ':'.
     */
    readonly mountPath: string;
    /**
     * Mount propagation mode.
     *
     * mount_propagation determines how mounts are propagated from the host to container and the other way around. Valid values are None (default), HostToContainer and Bidirectional.
     */
    readonly mountPropagation?: string;
    /**
     * This must match the Name of a Volume.
     */
    readonly name: string;
    /**
     * Mounted read-only if true, read-write otherwise (false or unspecified).
     *
     * Defaults to false.
     */
    readonly readOnly?: boolean;
    /**
     * Path within the volume from which the container's volume should be mounted.
     *
     * Defaults to "" (volume's root).
     */
    readonly subPath?: string;
}
/**
 *
 */
export interface PodSpecContainer {
    /**
     * Arguments to the entrypoint.
     *
     * The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     */
    readonly args?: string[];
    /**
     * Entrypoint array.
     *
     * Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     */
    readonly command?: string[];
    /**
     * Docker image name.
     *
     * More info: http://kubernetes.io/docs/user-guide/images
     */
    readonly image?: string;
    /**
     * Image pull policy.
     *
     * One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/images#updating-images
     */
    readonly imagePullPolicy?: string;
    /**
     * Name of the container specified as a DNS_LABEL.
     *
     * Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
     */
    readonly name: string;
    /**
     * Whether this container should allocate a buffer for stdin in the container runtime.
     *
     * If this is not set, reads from stdin in the container will always result in EOF.
     */
    readonly stdin?: boolean;
    /**
     * Whether the container runtime should close the stdin channel after it has been opened by a single attach.
     *
     * When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF.
     */
    readonly stdinOnce?: boolean;
    /**
     * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem.
     *
     * Message written is intended to be brief final status, such as an assertion failure message. Defaults to /dev/termination-log. Cannot be updated.
     */
    readonly terminationMessagePath?: string;
    /**
     * Optional: Indicate how the termination message should be populated.
     *
     * File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
     */
    readonly terminationMessagePolicy?: string;
    /**
     * Whether this container should allocate a TTY for itself.
     */
    readonly tty?: boolean;
    /**
     * Container's working directory.
     *
     * If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
     */
    readonly workingDir?: string;
    /**
     * env block.
     */
    readonly env?: PodSpecContainerEnv[];
    /**
     * env_from block.
     */
    readonly envFrom?: PodSpecContainerEnvFrom[];
    /**
     * lifecycle block.
     */
    readonly lifecycle?: PodSpecContainerLifecycle[];
    /**
     * liveness_probe block.
     */
    readonly livenessProbe?: PodSpecContainerLivenessProbe[];
    /**
     * port block.
     */
    readonly port?: PodSpecContainerPort[];
    /**
     * readiness_probe block.
     */
    readonly readinessProbe?: PodSpecContainerReadinessProbe[];
    /**
     * resources block.
     */
    readonly resources?: PodSpecContainerResources[];
    /**
     * security_context block.
     */
    readonly securityContext?: PodSpecContainerSecurityContext[];
    /**
     * startup_probe block.
     */
    readonly startupProbe?: PodSpecContainerStartupProbe[];
    /**
     * volume_mount block.
     */
    readonly volumeMount?: PodSpecContainerVolumeMount[];
}
/**
 *
 */
export interface PodSpecDnsConfigOption {
    /**
     * Name of the option.
     */
    readonly name: string;
    /**
     * Value of the option.
     *
     * Optional: Defaults to empty.
     */
    readonly value?: string;
}
/**
 *
 */
export interface PodSpecDnsConfig {
    /**
     * A list of DNS name server IP addresses.
     *
     * This will be appended to the base nameservers generated from DNSPolicy. Duplicated nameservers will be removed.
     */
    readonly nameservers?: string[];
    /**
     * A list of DNS search domains for host-name lookup.
     *
     * This will be appended to the base search paths generated from DNSPolicy. Duplicated search paths will be removed.
     */
    readonly searches?: string[];
    /**
     * option block.
     */
    readonly option?: PodSpecDnsConfigOption[];
}
/**
 *
 */
export interface PodSpecHostAliases {
    /**
     * Hostnames for the IP address.
     */
    readonly hostnames: string[];
    /**
     * IP address of the host file entry.
     */
    readonly ip: string;
}
/**
 *
 */
export interface PodSpecImagePullSecrets {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name: string;
}
/**
 *
 */
export interface PodSpecInitContainerEnvValueFromConfigMapKeyRef {
    /**
     * The key to select.
     */
    readonly key?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Specify whether the ConfigMap or its key must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface PodSpecInitContainerEnvValueFromFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     */
    readonly fieldPath?: string;
}
/**
 *
 */
export interface PodSpecInitContainerEnvValueFromResourceFieldRef {
    /**
     *
     */
    readonly containerName?: string;
    /**
     * Resource to select.
     */
    readonly resource: string;
}
/**
 *
 */
export interface PodSpecInitContainerEnvValueFromSecretKeyRef {
    /**
     * The key of the secret to select from.
     *
     * Must be a valid secret key.
     */
    readonly key?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Specify whether the Secret or its key must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface PodSpecInitContainerEnvValueFrom {
    /**
     * config_map_key_ref block.
     */
    readonly configMapKeyRef?: PodSpecInitContainerEnvValueFromConfigMapKeyRef[];
    /**
     * field_ref block.
     */
    readonly fieldRef?: PodSpecInitContainerEnvValueFromFieldRef[];
    /**
     * resource_field_ref block.
     */
    readonly resourceFieldRef?: PodSpecInitContainerEnvValueFromResourceFieldRef[];
    /**
     * secret_key_ref block.
     */
    readonly secretKeyRef?: PodSpecInitContainerEnvValueFromSecretKeyRef[];
}
/**
 *
 */
export interface PodSpecInitContainerEnv {
    /**
     * Name of the environment variable.
     *
     * Must be a C_IDENTIFIER
     */
    readonly name: string;
    /**
     * Variable references $(VAR_NAME) are expanded using the previous defined environment variables in the container and any service environment variables.
     *
     * If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
     */
    readonly value?: string;
    /**
     * value_from block.
     */
    readonly valueFrom?: PodSpecInitContainerEnvValueFrom[];
}
/**
 *
 */
export interface PodSpecInitContainerEnvFromConfigMapRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name: string;
    /**
     * Specify whether the ConfigMap must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface PodSpecInitContainerEnvFromSecretRef {
    /**
     * Name of the referent.
     *
     * More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
     */
    readonly name: string;
    /**
     * Specify whether the Secret must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface PodSpecInitContainerEnvFrom {
    /**
     * An optional identifer to prepend to each key in the ConfigMap.
     *
     * Must be a C_IDENTIFIER.
     */
    readonly prefix?: string;
    /**
     * config_map_ref block.
     */
    readonly configMapRef?: PodSpecInitContainerEnvFromConfigMapRef[];
    /**
     * secret_ref block.
     */
    readonly secretRef?: PodSpecInitContainerEnvFromSecretRef[];
}
/**
 *
 */
export interface PodSpecInitContainerLifecyclePostStartExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface PodSpecInitContainerLifecyclePostStartHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface PodSpecInitContainerLifecyclePostStartHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: PodSpecInitContainerLifecyclePostStartHttpGetHttpHeader[];
}
/**
 *
 */
export interface PodSpecInitContainerLifecyclePostStartTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface PodSpecInitContainerLifecyclePostStart {
    /**
     * exec block.
     */
    readonly exec?: PodSpecInitContainerLifecyclePostStartExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: PodSpecInitContainerLifecyclePostStartHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: PodSpecInitContainerLifecyclePostStartTcpSocket[];
}
/**
 *
 */
export interface PodSpecInitContainerLifecyclePreStopExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface PodSpecInitContainerLifecyclePreStopHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface PodSpecInitContainerLifecyclePreStopHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: PodSpecInitContainerLifecyclePreStopHttpGetHttpHeader[];
}
/**
 *
 */
export interface PodSpecInitContainerLifecyclePreStopTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface PodSpecInitContainerLifecyclePreStop {
    /**
     * exec block.
     */
    readonly exec?: PodSpecInitContainerLifecyclePreStopExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: PodSpecInitContainerLifecyclePreStopHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: PodSpecInitContainerLifecyclePreStopTcpSocket[];
}
/**
 *
 */
export interface PodSpecInitContainerLifecycle {
    /**
     * post_start block.
     */
    readonly postStart?: PodSpecInitContainerLifecyclePostStart[];
    /**
     * pre_stop block.
     */
    readonly preStop?: PodSpecInitContainerLifecyclePreStop[];
}
/**
 *
 */
export interface PodSpecInitContainerLivenessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface PodSpecInitContainerLivenessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface PodSpecInitContainerLivenessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: PodSpecInitContainerLivenessProbeHttpGetHttpHeader[];
}
/**
 *
 */
export interface PodSpecInitContainerLivenessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface PodSpecInitContainerLivenessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     */
    readonly exec?: PodSpecInitContainerLivenessProbeExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: PodSpecInitContainerLivenessProbeHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: PodSpecInitContainerLivenessProbeTcpSocket[];
}
/**
 *
 */
export interface PodSpecInitContainerPort {
    /**
     * Number of port to expose on the pod's IP address.
     *
     * This must be a valid port number, 0 < x < 65536.
     */
    readonly containerPort: number;
    /**
     * What host IP to bind the external port to.
     */
    readonly hostIp?: string;
    /**
     * Number of port to expose on the host.
     *
     * If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
     */
    readonly hostPort?: number;
    /**
     * If specified, this must be an IANA_SVC_NAME and unique within the pod.
     *
     * Each named port in a pod must have a unique name. Name for the port that can be referred to by services
     */
    readonly name?: string;
    /**
     * Protocol for port.
     *
     * Must be UDP or TCP. Defaults to "TCP".
     */
    readonly protocol?: string;
}
/**
 *
 */
export interface PodSpecInitContainerReadinessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface PodSpecInitContainerReadinessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface PodSpecInitContainerReadinessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: PodSpecInitContainerReadinessProbeHttpGetHttpHeader[];
}
/**
 *
 */
export interface PodSpecInitContainerReadinessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface PodSpecInitContainerReadinessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     */
    readonly exec?: PodSpecInitContainerReadinessProbeExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: PodSpecInitContainerReadinessProbeHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: PodSpecInitContainerReadinessProbeTcpSocket[];
}
/**
 *
 */
export interface PodSpecInitContainerResourcesLimits {
    /**
     *
     */
    readonly cpu?: string;
    /**
     *
     */
    readonly memory?: string;
}
/**
 *
 */
export interface PodSpecInitContainerResourcesRequests {
    /**
     *
     */
    readonly cpu?: string;
    /**
     *
     */
    readonly memory?: string;
}
/**
 *
 */
export interface PodSpecInitContainerResources {
    /**
     * limits block.
     */
    readonly limits?: PodSpecInitContainerResourcesLimits[];
    /**
     * requests block.
     */
    readonly requests?: PodSpecInitContainerResourcesRequests[];
}
/**
 *
 */
export interface PodSpecInitContainerSecurityContextCapabilities {
    /**
     * Added capabilities.
     */
    readonly add?: string[];
    /**
     * Removed capabilities.
     */
    readonly drop?: string[];
}
/**
 *
 */
export interface PodSpecInitContainerSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     */
    readonly user?: string;
}
/**
 *
 */
export interface PodSpecInitContainerSecurityContext {
    /**
     * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process.
     *
     * This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN
     */
    readonly allowPrivilegeEscalation?: boolean;
    /**
     * Run container in privileged mode.
     *
     * Processes in privileged containers are essentially equivalent to root on the host. Defaults to false.
     */
    readonly privileged?: boolean;
    /**
     * Whether this container has a read-only root filesystem.
     *
     * Default is false.
     */
    readonly readOnlyRootFilesystem?: boolean;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     */
    readonly runAsGroup?: number;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     */
    readonly runAsNonRoot?: boolean;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     */
    readonly runAsUser?: number;
    /**
     * capabilities block.
     */
    readonly capabilities?: PodSpecInitContainerSecurityContextCapabilities[];
    /**
     * se_linux_options block.
     */
    readonly seLinuxOptions?: PodSpecInitContainerSecurityContextSeLinuxOptions[];
}
/**
 *
 */
export interface PodSpecInitContainerStartupProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface PodSpecInitContainerStartupProbeHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface PodSpecInitContainerStartupProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: PodSpecInitContainerStartupProbeHttpGetHttpHeader[];
}
/**
 *
 */
export interface PodSpecInitContainerStartupProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface PodSpecInitContainerStartupProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     */
    readonly exec?: PodSpecInitContainerStartupProbeExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: PodSpecInitContainerStartupProbeHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: PodSpecInitContainerStartupProbeTcpSocket[];
}
/**
 *
 */
export interface PodSpecInitContainerVolumeMount {
    /**
     * Path within the container at which the volume should be mounted.
     *
     * Must not contain ':'.
     */
    readonly mountPath: string;
    /**
     * Mount propagation mode.
     *
     * mount_propagation determines how mounts are propagated from the host to container and the other way around. Valid values are None (default), HostToContainer and Bidirectional.
     */
    readonly mountPropagation?: string;
    /**
     * This must match the Name of a Volume.
     */
    readonly name: string;
    /**
     * Mounted read-only if true, read-write otherwise (false or unspecified).
     *
     * Defaults to false.
     */
    readonly readOnly?: boolean;
    /**
     * Path within the volume from which the container's volume should be mounted.
     *
     * Defaults to "" (volume's root).
     */
    readonly subPath?: string;
}
/**
 *
 */
export interface PodSpecInitContainer {
    /**
     * Arguments to the entrypoint.
     *
     * The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     */
    readonly args?: string[];
    /**
     * Entrypoint array.
     *
     * Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     */
    readonly command?: string[];
    /**
     * Docker image name.
     *
     * More info: http://kubernetes.io/docs/user-guide/images
     */
    readonly image?: string;
    /**
     * Image pull policy.
     *
     * One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/images#updating-images
     */
    readonly imagePullPolicy?: string;
    /**
     * Name of the container specified as a DNS_LABEL.
     *
     * Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
     */
    readonly name: string;
    /**
     * Whether this container should allocate a buffer for stdin in the container runtime.
     *
     * If this is not set, reads from stdin in the container will always result in EOF.
     */
    readonly stdin?: boolean;
    /**
     * Whether the container runtime should close the stdin channel after it has been opened by a single attach.
     *
     * When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF.
     */
    readonly stdinOnce?: boolean;
    /**
     * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem.
     *
     * Message written is intended to be brief final status, such as an assertion failure message. Defaults to /dev/termination-log. Cannot be updated.
     */
    readonly terminationMessagePath?: string;
    /**
     * Optional: Indicate how the termination message should be populated.
     *
     * File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
     */
    readonly terminationMessagePolicy?: string;
    /**
     * Whether this container should allocate a TTY for itself.
     */
    readonly tty?: boolean;
    /**
     * Container's working directory.
     *
     * If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
     */
    readonly workingDir?: string;
    /**
     * env block.
     */
    readonly env?: PodSpecInitContainerEnv[];
    /**
     * env_from block.
     */
    readonly envFrom?: PodSpecInitContainerEnvFrom[];
    /**
     * lifecycle block.
     */
    readonly lifecycle?: PodSpecInitContainerLifecycle[];
    /**
     * liveness_probe block.
     */
    readonly livenessProbe?: PodSpecInitContainerLivenessProbe[];
    /**
     * port block.
     */
    readonly port?: PodSpecInitContainerPort[];
    /**
     * readiness_probe block.
     */
    readonly readinessProbe?: PodSpecInitContainerReadinessProbe[];
    /**
     * resources block.
     */
    readonly resources?: PodSpecInitContainerResources[];
    /**
     * security_context block.
     */
    readonly securityContext?: PodSpecInitContainerSecurityContext[];
    /**
     * startup_probe block.
     */
    readonly startupProbe?: PodSpecInitContainerStartupProbe[];
    /**
     * volume_mount block.
     */
    readonly volumeMount?: PodSpecInitContainerVolumeMount[];
}
/**
 *
 */
export interface PodSpecSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     */
    readonly user?: string;
}
/**
 *
 */
export interface PodSpecSecurityContextSysctl {
    /**
     * Name of a property to set.
     */
    readonly name: string;
    /**
     * Value of a property to set.
     */
    readonly value: string;
}
/**
 *
 */
export interface PodSpecSecurityContext {
    /**
     * A special supplemental group that applies to all containers in a pod.
     *
     * Some volume types allow the Kubelet to change the ownership of that volume to be owned by the pod: 1. The owning GID will be the FSGroup 2. The setgid bit is set (new files created in the volume will be owned by FSGroup) 3. The permission bits are OR'd with rw-rw---- If unset, the Kubelet will not modify the ownership and permissions of any volume.
     */
    readonly fsGroup?: number;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.
     */
    readonly runAsGroup?: number;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     */
    readonly runAsNonRoot?: boolean;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.
     */
    readonly runAsUser?: number;
    /**
     * A list of groups applied to the first process run in each container, in addition to the container's primary GID.
     *
     * If unspecified, no groups will be added to any container.
     */
    readonly supplementalGroups?: number[];
    /**
     * se_linux_options block.
     */
    readonly seLinuxOptions?: PodSpecSecurityContextSeLinuxOptions[];
    /**
     * sysctl block.
     */
    readonly sysctl?: PodSpecSecurityContextSysctl[];
}
/**
 *
 */
export interface PodSpecToleration {
    /**
     * Effect indicates the taint effect to match.
     *
     * Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
     */
    readonly effect?: string;
    /**
     * Key is the taint key that the toleration applies to.
     *
     * Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to the value.
     *
     * Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
     */
    readonly operator?: string;
    /**
     * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint.
     *
     * By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.
     */
    readonly tolerationSeconds?: string;
    /**
     * Value is the taint value the toleration matches to.
     *
     * If the operator is Exists, the value should be empty, otherwise just a regular string.
     */
    readonly value?: string;
}
/**
 *
 */
export interface PodSpecVolumeAwsElasticBlockStore {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore
     */
    readonly fsType?: string;
    /**
     * The partition in the volume that you want to mount.
     *
     * If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty).
     */
    readonly partition?: number;
    /**
     * Whether to set the read-only property in VolumeMounts to "true".
     *
     * If omitted, the default is "false". More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore
     */
    readonly readOnly?: boolean;
    /**
     * Unique ID of the persistent disk resource in AWS (Amazon EBS volume).
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore
     */
    readonly volumeId: string;
}
/**
 *
 */
export interface PodSpecVolumeAzureDisk {
    /**
     * Host Caching mode: None, Read Only, Read Write.
     */
    readonly cachingMode: string;
    /**
     * The URI the data disk in the blob storage.
     */
    readonly dataDiskUri: string;
    /**
     * The Name of the data disk in the blob storage.
     */
    readonly diskName: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     */
    readonly fsType?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false (read/write).
     */
    readonly readOnly?: boolean;
}
/**
 *
 */
export interface PodSpecVolumeAzureFile {
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false (read/write).
     */
    readonly readOnly?: boolean;
    /**
     * The name of secret that contains Azure Storage Account Name and Key.
     */
    readonly secretName: string;
    /**
     * Share Name.
     */
    readonly shareName: string;
}
/**
 *
 */
export interface PodSpecVolumeCephFsSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface PodSpecVolumeCephFs {
    /**
     * Monitors is a collection of Ceph monitors More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     */
    readonly monitors: string[];
    /**
     * Used as the mounted root, rather than the full Ceph tree, default is /.
     */
    readonly path?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to `false` (read/write). More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it
     */
    readonly readOnly?: boolean;
    /**
     * The path to key ring for User, default is /etc/ceph/user.secret More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     */
    readonly secretFile?: string;
    /**
     * User is the rados user name, default is admin.
     *
     * More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it
     */
    readonly user?: string;
    /**
     * secret_ref block.
     */
    readonly secretRef?: PodSpecVolumeCephFsSecretRef[];
}
/**
 *
 */
export interface PodSpecVolumeCinder {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md
     */
    readonly fsType?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false (read/write). More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md
     */
    readonly readOnly?: boolean;
    /**
     * Volume ID used to identify the volume in Cinder.
     *
     * More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md
     */
    readonly volumeId: string;
}
/**
 *
 */
export interface PodSpecVolumeConfigMapItems {
    /**
     * The key to project.
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     */
    readonly path?: string;
}
/**
 *
 */
export interface PodSpecVolumeConfigMap {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly defaultMode?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the ConfigMap or its keys must be defined.
     */
    readonly optional?: boolean;
    /**
     * items block.
     */
    readonly items?: PodSpecVolumeConfigMapItems[];
}
/**
 *
 */
export interface PodSpecVolumeCsiControllerExpandSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface PodSpecVolumeCsiControllerPublishSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface PodSpecVolumeCsiNodePublishSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface PodSpecVolumeCsiNodeStageSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface PodSpecVolumeCsi {
    /**
     * the name of the volume driver to use.
     *
     * More info: https://kubernetes.io/docs/concepts/storage/volumes/#csi
     */
    readonly driver: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     */
    readonly fsType?: string;
    /**
     * Whether to set the read-only property in VolumeMounts to "true".
     *
     * If omitted, the default is "false". More info: http://kubernetes.io/docs/user-guide/volumes#csi
     */
    readonly readOnly?: boolean;
    /**
     * Attributes of the volume to publish.
     */
    readonly volumeAttributes?: {
        [key: string]: string;
    };
    /**
     * A string value that uniquely identifies the volume.
     *
     * More info: https://kubernetes.io/docs/concepts/storage/volumes/#csi
     */
    readonly volumeHandle: string;
    /**
     * controller_expand_secret_ref block.
     */
    readonly controllerExpandSecretRef?: PodSpecVolumeCsiControllerExpandSecretRef[];
    /**
     * controller_publish_secret_ref block.
     */
    readonly controllerPublishSecretRef?: PodSpecVolumeCsiControllerPublishSecretRef[];
    /**
     * node_publish_secret_ref block.
     */
    readonly nodePublishSecretRef?: PodSpecVolumeCsiNodePublishSecretRef[];
    /**
     * node_stage_secret_ref block.
     */
    readonly nodeStageSecretRef?: PodSpecVolumeCsiNodeStageSecretRef[];
}
/**
 *
 */
export interface PodSpecVolumeDownwardApiItemsFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     */
    readonly fieldPath?: string;
}
/**
 *
 */
export interface PodSpecVolumeDownwardApiItemsResourceFieldRef {
    /**
     *
     */
    readonly containerName: string;
    /**
     *
     */
    readonly quantity?: string;
    /**
     * Resource to select.
     */
    readonly resource: string;
}
/**
 *
 */
export interface PodSpecVolumeDownwardApiItems {
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly mode?: string;
    /**
     * Path is the relative path name of the file to be created.
     *
     * Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
     */
    readonly path: string;
    /**
     * field_ref block.
     */
    readonly fieldRef: PodSpecVolumeDownwardApiItemsFieldRef[];
    /**
     * resource_field_ref block.
     */
    readonly resourceFieldRef?: PodSpecVolumeDownwardApiItemsResourceFieldRef[];
}
/**
 *
 */
export interface PodSpecVolumeDownwardApi {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly defaultMode?: string;
    /**
     * items block.
     */
    readonly items?: PodSpecVolumeDownwardApiItems[];
}
/**
 *
 */
export interface PodSpecVolumeEmptyDir {
    /**
     * What type of storage medium should back this directory.
     *
     * The default is "" which means to use the node's default medium. Must be an empty string (default) or Memory. More info: http://kubernetes.io/docs/user-guide/volumes#emptydir
     */
    readonly medium?: string;
    /**
     * Total amount of local storage required for this EmptyDir volume.
     */
    readonly sizeLimit?: string;
}
/**
 *
 */
export interface PodSpecVolumeFc {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     */
    readonly fsType?: string;
    /**
     * FC target lun number.
     */
    readonly lun: number;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false (read/write).
     */
    readonly readOnly?: boolean;
    /**
     * FC target worldwide names (WWNs).
     */
    readonly targetWwNs: string[];
}
/**
 *
 */
export interface PodSpecVolumeFlexVolumeSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface PodSpecVolumeFlexVolume {
    /**
     * Driver is the name of the driver to use for this volume.
     */
    readonly driver: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default filesystem depends on FlexVolume script.
     */
    readonly fsType?: string;
    /**
     * Extra command options if any.
     */
    readonly options?: {
        [key: string]: string;
    };
    /**
     * Whether to force the ReadOnly setting in VolumeMounts.
     *
     * Defaults to false (read/write).
     */
    readonly readOnly?: boolean;
    /**
     * secret_ref block.
     */
    readonly secretRef?: PodSpecVolumeFlexVolumeSecretRef[];
}
/**
 *
 */
export interface PodSpecVolumeFlocker {
    /**
     * Name of the dataset stored as metadata -> name on the dataset for Flocker should be considered as deprecated.
     */
    readonly datasetName?: string;
    /**
     * UUID of the dataset.
     *
     * This is unique identifier of a Flocker dataset
     */
    readonly datasetUuid?: string;
}
/**
 *
 */
export interface PodSpecVolumeGcePersistentDisk {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     */
    readonly fsType?: string;
    /**
     * The partition in the volume that you want to mount.
     *
     * If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty). More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     */
    readonly partition?: number;
    /**
     * Unique name of the PD resource in GCE.
     *
     * Used to identify the disk in GCE. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     */
    readonly pdName: string;
    /**
     * Whether to force the ReadOnly setting in VolumeMounts.
     *
     * Defaults to false. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     */
    readonly readOnly?: boolean;
}
/**
 *
 */
export interface PodSpecVolumeGitRepo {
    /**
     * Target directory name.
     *
     * Must not contain or start with '..'. If '.' is supplied, the volume directory will be the git repository. Otherwise, if specified, the volume will contain the git repository in the subdirectory with the given name.
     */
    readonly directory?: string;
    /**
     * Repository URL.
     */
    readonly repository?: string;
    /**
     * Commit hash for the specified revision.
     */
    readonly revision?: string;
}
/**
 *
 */
export interface PodSpecVolumeGlusterfs {
    /**
     * The endpoint name that details Glusterfs topology.
     *
     * More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod
     */
    readonly endpointsName: string;
    /**
     * The Glusterfs volume path.
     *
     * More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod
     */
    readonly path: string;
    /**
     * Whether to force the Glusterfs volume to be mounted with read-only permissions.
     *
     * Defaults to false. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod
     */
    readonly readOnly?: boolean;
}
/**
 *
 */
export interface PodSpecVolumeHostPath {
    /**
     * Path of the directory on the host.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#hostpath
     */
    readonly path?: string;
    /**
     * Type for HostPath volume.
     *
     * Allowed values are "" (default), DirectoryOrCreate, Directory, FileOrCreate, File, Socket, CharDevice and BlockDevice
     */
    readonly type?: string;
}
/**
 *
 */
export interface PodSpecVolumeIscsi {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#iscsi
     */
    readonly fsType?: string;
    /**
     * Target iSCSI Qualified Name.
     */
    readonly iqn: string;
    /**
     * iSCSI interface name that uses an iSCSI transport.
     *
     * Defaults to 'default' (tcp).
     */
    readonly iscsiInterface?: string;
    /**
     * iSCSI target lun number.
     */
    readonly lun?: number;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false.
     */
    readonly readOnly?: boolean;
    /**
     * iSCSI target portal.
     *
     * The portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).
     */
    readonly targetPortal: string;
}
/**
 *
 */
export interface PodSpecVolumeLocal {
    /**
     * Path of the directory on the host.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#local
     */
    readonly path?: string;
}
/**
 *
 */
export interface PodSpecVolumeNfs {
    /**
     * Path that is exported by the NFS server.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#nfs
     */
    readonly path: string;
    /**
     * Whether to force the NFS export to be mounted with read-only permissions.
     *
     * Defaults to false. More info: http://kubernetes.io/docs/user-guide/volumes#nfs
     */
    readonly readOnly?: boolean;
    /**
     * Server is the hostname or IP address of the NFS server.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#nfs
     */
    readonly server: string;
}
/**
 *
 */
export interface PodSpecVolumePersistentVolumeClaim {
    /**
     * ClaimName is the name of a PersistentVolumeClaim in the same.
     */
    readonly claimName?: string;
    /**
     * Will force the ReadOnly setting in VolumeMounts.
     */
    readonly readOnly?: boolean;
}
/**
 *
 */
export interface PodSpecVolumePhotonPersistentDisk {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     */
    readonly fsType?: string;
    /**
     * ID that identifies Photon Controller persistent disk.
     */
    readonly pdId: string;
}
/**
 *
 */
export interface PodSpecVolumeProjectedSourcesConfigMapItems {
    /**
     * The key to project.
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     */
    readonly path?: string;
}
/**
 *
 */
export interface PodSpecVolumeProjectedSourcesConfigMap {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the ConfigMap or it's keys must be defined.
     */
    readonly optional?: boolean;
    /**
     * items block.
     */
    readonly items?: PodSpecVolumeProjectedSourcesConfigMapItems[];
}
/**
 *
 */
export interface PodSpecVolumeProjectedSourcesDownwardApiItemsFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to 'v1'.
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     */
    readonly fieldPath?: string;
}
/**
 *
 */
export interface PodSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef {
    /**
     *
     */
    readonly containerName: string;
    /**
     *
     */
    readonly quantity?: string;
    /**
     * Resource to select.
     */
    readonly resource: string;
}
/**
 *
 */
export interface PodSpecVolumeProjectedSourcesDownwardApiItems {
    /**
     * Mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly mode?: string;
    /**
     * Path is the relative path name of the file to be created.
     *
     * Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
     */
    readonly path: string;
    /**
     * field_ref block.
     */
    readonly fieldRef?: PodSpecVolumeProjectedSourcesDownwardApiItemsFieldRef[];
    /**
     * resource_field_ref block.
     */
    readonly resourceFieldRef?: PodSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef[];
}
/**
 *
 */
export interface PodSpecVolumeProjectedSourcesDownwardApi {
    /**
     * items block.
     */
    readonly items?: PodSpecVolumeProjectedSourcesDownwardApiItems[];
}
/**
 *
 */
export interface PodSpecVolumeProjectedSourcesSecretItems {
    /**
     * The key to project.
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     */
    readonly path?: string;
}
/**
 *
 */
export interface PodSpecVolumeProjectedSourcesSecret {
    /**
     * Name of the secret in the pod's namespace to use.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#secrets
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the Secret or it's keys must be defined.
     */
    readonly optional?: boolean;
    /**
     * items block.
     */
    readonly items?: PodSpecVolumeProjectedSourcesSecretItems[];
}
/**
 *
 */
export interface PodSpecVolumeProjectedSourcesServiceAccountToken {
    /**
     * Audience is the intended audience of the token.
     */
    readonly audience?: string;
    /**
     * ExpirationSeconds is the expected duration of validity of the service account token.
     *
     * It defaults to 1 hour and must be at least 10 minutes (600 seconds).
     */
    readonly expirationSeconds?: number;
    /**
     * Path specifies a relative path to the mount point of the projected volume.
     */
    readonly path: string;
}
/**
 *
 */
export interface PodSpecVolumeProjectedSources {
    /**
     * config_map block.
     */
    readonly configMap?: PodSpecVolumeProjectedSourcesConfigMap[];
    /**
     * downward_api block.
     */
    readonly downwardApi?: PodSpecVolumeProjectedSourcesDownwardApi[];
    /**
     * secret block.
     */
    readonly secret?: PodSpecVolumeProjectedSourcesSecret[];
    /**
     * service_account_token block.
     */
    readonly serviceAccountToken?: PodSpecVolumeProjectedSourcesServiceAccountToken[];
}
/**
 *
 */
export interface PodSpecVolumeProjected {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly defaultMode?: string;
    /**
     * sources block.
     */
    readonly sources: PodSpecVolumeProjectedSources[];
}
/**
 *
 */
export interface PodSpecVolumeQuobyte {
    /**
     * Group to map volume access to Default is no group.
     */
    readonly group?: string;
    /**
     * Whether to force the Quobyte volume to be mounted with read-only permissions.
     *
     * Defaults to false.
     */
    readonly readOnly?: boolean;
    /**
     * Registry represents a single or multiple Quobyte Registry services specified as a string as host:port pair (multiple entries are separated with commas) which acts as the central registry for volumes.
     */
    readonly registry: string;
    /**
     * User to map volume access to Defaults to serivceaccount user.
     */
    readonly user?: string;
    /**
     * Volume is a string that references an already created Quobyte volume by name.
     */
    readonly volume: string;
}
/**
 *
 */
export interface PodSpecVolumeRbdSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface PodSpecVolumeRbd {
    /**
     * A collection of Ceph monitors.
     *
     * More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it
     */
    readonly cephMonitors: string[];
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#rbd
     */
    readonly fsType?: string;
    /**
     * Keyring is the path to key ring for RBDUser.
     *
     * Default is /etc/ceph/keyring. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it
     */
    readonly keyring?: string;
    /**
     * The rados user name.
     *
     * Default is admin. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it
     */
    readonly radosUser?: string;
    /**
     * The rados image name.
     *
     * More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it
     */
    readonly rbdImage: string;
    /**
     * The rados pool name.
     *
     * Default is rbd. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     */
    readonly rbdPool?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it
     */
    readonly readOnly?: boolean;
    /**
     * secret_ref block.
     */
    readonly secretRef?: PodSpecVolumeRbdSecretRef[];
}
/**
 *
 */
export interface PodSpecVolumeSecretItems {
    /**
     * The key to project.
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     */
    readonly path?: string;
}
/**
 *
 */
export interface PodSpecVolumeSecret {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly defaultMode?: string;
    /**
     * Optional: Specify whether the Secret or its keys must be defined.
     */
    readonly optional?: boolean;
    /**
     * Name of the secret in the pod's namespace to use.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#secrets
     */
    readonly secretName?: string;
    /**
     * items block.
     */
    readonly items?: PodSpecVolumeSecretItems[];
}
/**
 *
 */
export interface PodSpecVolumeVsphereVolume {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     */
    readonly fsType?: string;
    /**
     * Path that identifies vSphere volume vmdk.
     */
    readonly volumePath: string;
}
/**
 *
 */
export interface PodSpecVolume {
    /**
     * Volume's name.
     *
     * Must be a DNS_LABEL and unique within the pod. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * aws_elastic_block_store block.
     */
    readonly awsElasticBlockStore?: PodSpecVolumeAwsElasticBlockStore[];
    /**
     * azure_disk block.
     */
    readonly azureDisk?: PodSpecVolumeAzureDisk[];
    /**
     * azure_file block.
     */
    readonly azureFile?: PodSpecVolumeAzureFile[];
    /**
     * ceph_fs block.
     */
    readonly cephFs?: PodSpecVolumeCephFs[];
    /**
     * cinder block.
     */
    readonly cinder?: PodSpecVolumeCinder[];
    /**
     * config_map block.
     */
    readonly configMap?: PodSpecVolumeConfigMap[];
    /**
     * csi block.
     */
    readonly csi?: PodSpecVolumeCsi[];
    /**
     * downward_api block.
     */
    readonly downwardApi?: PodSpecVolumeDownwardApi[];
    /**
     * empty_dir block.
     */
    readonly emptyDir?: PodSpecVolumeEmptyDir[];
    /**
     * fc block.
     */
    readonly fc?: PodSpecVolumeFc[];
    /**
     * flex_volume block.
     */
    readonly flexVolume?: PodSpecVolumeFlexVolume[];
    /**
     * flocker block.
     */
    readonly flocker?: PodSpecVolumeFlocker[];
    /**
     * gce_persistent_disk block.
     */
    readonly gcePersistentDisk?: PodSpecVolumeGcePersistentDisk[];
    /**
     * git_repo block.
     */
    readonly gitRepo?: PodSpecVolumeGitRepo[];
    /**
     * glusterfs block.
     */
    readonly glusterfs?: PodSpecVolumeGlusterfs[];
    /**
     * host_path block.
     */
    readonly hostPath?: PodSpecVolumeHostPath[];
    /**
     * iscsi block.
     */
    readonly iscsi?: PodSpecVolumeIscsi[];
    /**
     * local block.
     */
    readonly local?: PodSpecVolumeLocal[];
    /**
     * nfs block.
     */
    readonly nfs?: PodSpecVolumeNfs[];
    /**
     * persistent_volume_claim block.
     */
    readonly persistentVolumeClaim?: PodSpecVolumePersistentVolumeClaim[];
    /**
     * photon_persistent_disk block.
     */
    readonly photonPersistentDisk?: PodSpecVolumePhotonPersistentDisk[];
    /**
     * projected block.
     */
    readonly projected?: PodSpecVolumeProjected[];
    /**
     * quobyte block.
     */
    readonly quobyte?: PodSpecVolumeQuobyte[];
    /**
     * rbd block.
     */
    readonly rbd?: PodSpecVolumeRbd[];
    /**
     * secret block.
     */
    readonly secret?: PodSpecVolumeSecret[];
    /**
     * vsphere_volume block.
     */
    readonly vsphereVolume?: PodSpecVolumeVsphereVolume[];
}
/**
 *
 */
export interface PodSpec {
    /**
     * Optional duration in seconds the pod may be active on the node relative to StartTime before the system will actively try to mark it failed and kill associated containers.
     *
     * Value must be a positive integer.
     */
    readonly activeDeadlineSeconds?: number;
    /**
     * AutomountServiceAccountToken indicates whether a service account token should be automatically mounted.
     */
    readonly automountServiceAccountToken?: boolean;
    /**
     * Set DNS policy for containers within the pod.
     *
     * Valid values are 'ClusterFirstWithHostNet', 'ClusterFirst', 'Default' or 'None'. DNS parameters given in DNSConfig will be merged with the policy selected with DNSPolicy. To have DNS options set along with hostNetwork, you have to specify DNS policy explicitly to 'ClusterFirstWithHostNet'. Optional: Defaults to 'ClusterFirst', see [Kubernetes reference](https://kubernetes.io/docs/concepts/services-networking/dns-pod-service/#pod-s-dns-policy).
     */
    readonly dnsPolicy?: string;
    /**
     * Use the host's ipc namespace.
     *
     * Optional: Defaults to false.
     */
    readonly hostIpc?: boolean;
    /**
     * Host networking requested for this pod.
     *
     * Use the host's network namespace. If this option is set, the ports that will be used must be specified.
     */
    readonly hostNetwork?: boolean;
    /**
     * Use the host's pid namespace.
     */
    readonly hostPid?: boolean;
    /**
     * Specifies the hostname of the Pod If not specified, the pod's hostname will be set to a system-defined value.
     */
    readonly hostname?: string;
    /**
     * NodeName is a request to schedule this pod onto a specific node.
     *
     * If it is non-empty, the scheduler simply schedules this pod onto that node, assuming that it fits resource requirements.
     */
    readonly nodeName?: string;
    /**
     * NodeSelector is a selector which must be true for the pod to fit on a node.
     *
     * Selector which must match a node's labels for the pod to be scheduled on that node. More info: http://kubernetes.io/docs/user-guide/node-selection.
     */
    readonly nodeSelector?: {
        [key: string]: string;
    };
    /**
     * If specified, indicates the pod's priority.
     *
     * "system-node-critical" and "system-cluster-critical" are two special keywords which indicate the highest priorities with the former being the highest priority. Any other name must be defined by creating a PriorityClass object with that name. If not specified, the pod priority will be default or zero if there is no default.
     */
    readonly priorityClassName?: string;
    /**
     * Restart policy for all containers within the pod.
     *
     * One of Always, OnFailure, Never. More info: http://kubernetes.io/docs/user-guide/pod-states#restartpolicy.
     */
    readonly restartPolicy?: string;
    /**
     * ServiceAccountName is the name of the ServiceAccount to use to run this pod.
     *
     * More info: http://releases.k8s.io/HEAD/docs/design/service_accounts.md.
     */
    readonly serviceAccountName?: string;
    /**
     * Share a single process namespace between all of the containers in a pod.
     *
     * When this is set containers will be able to view and signal processes from other containers in the same pod, and the first process in each container will not be assigned PID 1. HostPID and ShareProcessNamespace cannot both be set. Optional: Defaults to false.
     */
    readonly shareProcessNamespace?: boolean;
    /**
     * If specified, the fully qualified Pod hostname will be "...svc.". If not specified, the pod will not have a domainname at all..
     */
    readonly subdomain?: string;
    /**
     * Optional duration in seconds the pod needs to terminate gracefully.
     *
     * May be decreased in delete request. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period will be used instead. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process.
     */
    readonly terminationGracePeriodSeconds?: number;
    /**
     * affinity block.
     */
    readonly affinity?: PodSpecAffinity[];
    /**
     * container block.
     */
    readonly container?: PodSpecContainer[];
    /**
     * dns_config block.
     */
    readonly dnsConfig?: PodSpecDnsConfig[];
    /**
     * host_aliases block.
     */
    readonly hostAliases?: PodSpecHostAliases[];
    /**
     * image_pull_secrets block.
     */
    readonly imagePullSecrets?: PodSpecImagePullSecrets[];
    /**
     * init_container block.
     */
    readonly initContainer?: PodSpecInitContainer[];
    /**
     * security_context block.
     */
    readonly securityContext?: PodSpecSecurityContext[];
    /**
     * toleration block.
     */
    readonly toleration?: PodSpecToleration[];
    /**
     * volume block.
     */
    readonly volume?: PodSpecVolume[];
}
/**
 *
 */
export interface PodTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
}
/**
 *
 */
export declare class Pod extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: PodConfig);
    private _id?;
    /**
     *
     */
    get id(): string | undefined;
    /**
     *
     */
    set id(value: string | undefined);
    private _metadata;
    /**
     *
     */
    get metadata(): PodMetadata[];
    /**
     *
     */
    set metadata(value: PodMetadata[]);
    private _spec;
    /**
     *
     */
    get spec(): PodSpec[];
    /**
     *
     */
    set spec(value: PodSpec[]);
    private _timeouts?;
    /**
     *
     */
    get timeouts(): PodTimeouts | undefined;
    /**
     *
     */
    set timeouts(value: PodTimeouts | undefined);
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
