import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ReplicationControllerConfig extends TerraformMetaArguments {
    /**
     * metadata block.
     */
    readonly metadata: ReplicationControllerMetadata[];
    /**
     * spec block.
     */
    readonly spec: ReplicationControllerSpec[];
    /**
     * timeouts block.
     */
    readonly timeouts?: ReplicationControllerTimeouts;
}
/**
 *
 */
export interface ReplicationControllerMetadata {
    /**
     * An unstructured key value map stored with the replication controller that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the replication controller.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the replication controller, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the replication controller must be unique.
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions {
    /**
     * The label key that the selector applies to.
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to a set of values.
     *
     * Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
     */
    readonly operator?: string;
    /**
     * Values is an array of string values.
     *
     * If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference {
    /**
     * match_expressions block.
     */
    readonly matchExpressions?: ReplicationControllerSpecTemplateAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight is in the range 1-100.
     */
    readonly weight: number;
    /**
     * preference block.
     */
    readonly preference: ReplicationControllerSpecTemplateAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions {
    /**
     * The label key that the selector applies to.
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to a set of values.
     *
     * Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
     */
    readonly operator?: string;
    /**
     * Values is an array of string values.
     *
     * If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm {
    /**
     * match_expressions block.
     */
    readonly matchExpressions?: ReplicationControllerSpecTemplateAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * node_selector_term block.
     */
    readonly nodeSelectorTerm?: ReplicationControllerSpecTemplateAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityNodeAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: ReplicationControllerSpecTemplateAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: ReplicationControllerSpecTemplateAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     */
    readonly matchExpressions?: ReplicationControllerSpecTemplateAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against);
     *
     * null or empty list means 'this pod's namespace'
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     */
    readonly labelSelector?: ReplicationControllerSpecTemplateAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
     */
    readonly weight: number;
    /**
     * pod_affinity_term block.
     */
    readonly podAffinityTerm: ReplicationControllerSpecTemplateAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     */
    readonly matchExpressions?: ReplicationControllerSpecTemplateAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against);
     *
     * null or empty list means 'this pod's namespace'
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     */
    readonly labelSelector?: ReplicationControllerSpecTemplateAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityPodAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: ReplicationControllerSpecTemplateAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: ReplicationControllerSpecTemplateAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     */
    readonly matchExpressions?: ReplicationControllerSpecTemplateAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against);
     *
     * null or empty list means 'this pod's namespace'
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     */
    readonly labelSelector?: ReplicationControllerSpecTemplateAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
     */
    readonly weight: number;
    /**
     * pod_affinity_term block.
     */
    readonly podAffinityTerm: ReplicationControllerSpecTemplateAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     */
    readonly matchExpressions?: ReplicationControllerSpecTemplateAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against);
     *
     * null or empty list means 'this pod's namespace'
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     */
    readonly labelSelector?: ReplicationControllerSpecTemplateAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinityPodAntiAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: ReplicationControllerSpecTemplateAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: ReplicationControllerSpecTemplateAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateAffinity {
    /**
     * node_affinity block.
     */
    readonly nodeAffinity?: ReplicationControllerSpecTemplateAffinityNodeAffinity[];
    /**
     * pod_affinity block.
     */
    readonly podAffinity?: ReplicationControllerSpecTemplateAffinityPodAffinity[];
    /**
     * pod_anti_affinity block.
     */
    readonly podAntiAffinity?: ReplicationControllerSpecTemplateAffinityPodAntiAffinity[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerEnvValueFromConfigMapKeyRef {
    /**
     * The key to select.
     */
    readonly key?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Specify whether the ConfigMap or its key must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerEnvValueFromFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     */
    readonly fieldPath?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerEnvValueFromResourceFieldRef {
    /**
     *
     */
    readonly containerName?: string;
    /**
     * Resource to select.
     */
    readonly resource: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerEnvValueFromSecretKeyRef {
    /**
     * The key of the secret to select from.
     *
     * Must be a valid secret key.
     */
    readonly key?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Specify whether the Secret or its key must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerEnvValueFrom {
    /**
     * config_map_key_ref block.
     */
    readonly configMapKeyRef?: ReplicationControllerSpecTemplateContainerEnvValueFromConfigMapKeyRef[];
    /**
     * field_ref block.
     */
    readonly fieldRef?: ReplicationControllerSpecTemplateContainerEnvValueFromFieldRef[];
    /**
     * resource_field_ref block.
     */
    readonly resourceFieldRef?: ReplicationControllerSpecTemplateContainerEnvValueFromResourceFieldRef[];
    /**
     * secret_key_ref block.
     */
    readonly secretKeyRef?: ReplicationControllerSpecTemplateContainerEnvValueFromSecretKeyRef[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerEnv {
    /**
     * Name of the environment variable.
     *
     * Must be a C_IDENTIFIER
     */
    readonly name: string;
    /**
     * Variable references $(VAR_NAME) are expanded using the previous defined environment variables in the container and any service environment variables.
     *
     * If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
     */
    readonly value?: string;
    /**
     * value_from block.
     */
    readonly valueFrom?: ReplicationControllerSpecTemplateContainerEnvValueFrom[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerEnvFromConfigMapRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name: string;
    /**
     * Specify whether the ConfigMap must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerEnvFromSecretRef {
    /**
     * Name of the referent.
     *
     * More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
     */
    readonly name: string;
    /**
     * Specify whether the Secret must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerEnvFrom {
    /**
     * An optional identifer to prepend to each key in the ConfigMap.
     *
     * Must be a C_IDENTIFIER.
     */
    readonly prefix?: string;
    /**
     * config_map_ref block.
     */
    readonly configMapRef?: ReplicationControllerSpecTemplateContainerEnvFromConfigMapRef[];
    /**
     * secret_ref block.
     */
    readonly secretRef?: ReplicationControllerSpecTemplateContainerEnvFromSecretRef[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerLifecyclePostStartExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerLifecyclePostStartHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerLifecyclePostStartHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: ReplicationControllerSpecTemplateContainerLifecyclePostStartHttpGetHttpHeader[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerLifecyclePostStartTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerLifecyclePostStart {
    /**
     * exec block.
     */
    readonly exec?: ReplicationControllerSpecTemplateContainerLifecyclePostStartExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: ReplicationControllerSpecTemplateContainerLifecyclePostStartHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: ReplicationControllerSpecTemplateContainerLifecyclePostStartTcpSocket[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerLifecyclePreStopExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerLifecyclePreStopHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerLifecyclePreStopHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: ReplicationControllerSpecTemplateContainerLifecyclePreStopHttpGetHttpHeader[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerLifecyclePreStopTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerLifecyclePreStop {
    /**
     * exec block.
     */
    readonly exec?: ReplicationControllerSpecTemplateContainerLifecyclePreStopExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: ReplicationControllerSpecTemplateContainerLifecyclePreStopHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: ReplicationControllerSpecTemplateContainerLifecyclePreStopTcpSocket[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerLifecycle {
    /**
     * post_start block.
     */
    readonly postStart?: ReplicationControllerSpecTemplateContainerLifecyclePostStart[];
    /**
     * pre_stop block.
     */
    readonly preStop?: ReplicationControllerSpecTemplateContainerLifecyclePreStop[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerLivenessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerLivenessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerLivenessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: ReplicationControllerSpecTemplateContainerLivenessProbeHttpGetHttpHeader[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerLivenessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerLivenessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     */
    readonly exec?: ReplicationControllerSpecTemplateContainerLivenessProbeExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: ReplicationControllerSpecTemplateContainerLivenessProbeHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: ReplicationControllerSpecTemplateContainerLivenessProbeTcpSocket[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerPort {
    /**
     * Number of port to expose on the pod's IP address.
     *
     * This must be a valid port number, 0 < x < 65536.
     */
    readonly containerPort: number;
    /**
     * What host IP to bind the external port to.
     */
    readonly hostIp?: string;
    /**
     * Number of port to expose on the host.
     *
     * If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
     */
    readonly hostPort?: number;
    /**
     * If specified, this must be an IANA_SVC_NAME and unique within the pod.
     *
     * Each named port in a pod must have a unique name. Name for the port that can be referred to by services
     */
    readonly name?: string;
    /**
     * Protocol for port.
     *
     * Must be UDP or TCP. Defaults to "TCP".
     */
    readonly protocol?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerReadinessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerReadinessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerReadinessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: ReplicationControllerSpecTemplateContainerReadinessProbeHttpGetHttpHeader[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerReadinessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerReadinessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     */
    readonly exec?: ReplicationControllerSpecTemplateContainerReadinessProbeExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: ReplicationControllerSpecTemplateContainerReadinessProbeHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: ReplicationControllerSpecTemplateContainerReadinessProbeTcpSocket[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerResourcesLimits {
    /**
     *
     */
    readonly cpu?: string;
    /**
     *
     */
    readonly memory?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerResourcesRequests {
    /**
     *
     */
    readonly cpu?: string;
    /**
     *
     */
    readonly memory?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerResources {
    /**
     * limits block.
     */
    readonly limits?: ReplicationControllerSpecTemplateContainerResourcesLimits[];
    /**
     * requests block.
     */
    readonly requests?: ReplicationControllerSpecTemplateContainerResourcesRequests[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerSecurityContextCapabilities {
    /**
     * Added capabilities.
     */
    readonly add?: string[];
    /**
     * Removed capabilities.
     */
    readonly drop?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     */
    readonly user?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerSecurityContext {
    /**
     * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process.
     *
     * This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN
     */
    readonly allowPrivilegeEscalation?: boolean;
    /**
     * Run container in privileged mode.
     *
     * Processes in privileged containers are essentially equivalent to root on the host. Defaults to false.
     */
    readonly privileged?: boolean;
    /**
     * Whether this container has a read-only root filesystem.
     *
     * Default is false.
     */
    readonly readOnlyRootFilesystem?: boolean;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     */
    readonly runAsGroup?: number;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     */
    readonly runAsNonRoot?: boolean;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     */
    readonly runAsUser?: number;
    /**
     * capabilities block.
     */
    readonly capabilities?: ReplicationControllerSpecTemplateContainerSecurityContextCapabilities[];
    /**
     * se_linux_options block.
     */
    readonly seLinuxOptions?: ReplicationControllerSpecTemplateContainerSecurityContextSeLinuxOptions[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerStartupProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerStartupProbeHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerStartupProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: ReplicationControllerSpecTemplateContainerStartupProbeHttpGetHttpHeader[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerStartupProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerStartupProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     */
    readonly exec?: ReplicationControllerSpecTemplateContainerStartupProbeExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: ReplicationControllerSpecTemplateContainerStartupProbeHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: ReplicationControllerSpecTemplateContainerStartupProbeTcpSocket[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainerVolumeMount {
    /**
     * Path within the container at which the volume should be mounted.
     *
     * Must not contain ':'.
     */
    readonly mountPath: string;
    /**
     * Mount propagation mode.
     *
     * mount_propagation determines how mounts are propagated from the host to container and the other way around. Valid values are None (default), HostToContainer and Bidirectional.
     */
    readonly mountPropagation?: string;
    /**
     * This must match the Name of a Volume.
     */
    readonly name: string;
    /**
     * Mounted read-only if true, read-write otherwise (false or unspecified).
     *
     * Defaults to false.
     */
    readonly readOnly?: boolean;
    /**
     * Path within the volume from which the container's volume should be mounted.
     *
     * Defaults to "" (volume's root).
     */
    readonly subPath?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateContainer {
    /**
     * Arguments to the entrypoint.
     *
     * The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     */
    readonly args?: string[];
    /**
     * Entrypoint array.
     *
     * Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     */
    readonly command?: string[];
    /**
     * Docker image name.
     *
     * More info: http://kubernetes.io/docs/user-guide/images
     */
    readonly image?: string;
    /**
     * Image pull policy.
     *
     * One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/images#updating-images
     */
    readonly imagePullPolicy?: string;
    /**
     * Name of the container specified as a DNS_LABEL.
     *
     * Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
     */
    readonly name: string;
    /**
     * Whether this container should allocate a buffer for stdin in the container runtime.
     *
     * If this is not set, reads from stdin in the container will always result in EOF.
     */
    readonly stdin?: boolean;
    /**
     * Whether the container runtime should close the stdin channel after it has been opened by a single attach.
     *
     * When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF.
     */
    readonly stdinOnce?: boolean;
    /**
     * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem.
     *
     * Message written is intended to be brief final status, such as an assertion failure message. Defaults to /dev/termination-log. Cannot be updated.
     */
    readonly terminationMessagePath?: string;
    /**
     * Optional: Indicate how the termination message should be populated.
     *
     * File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
     */
    readonly terminationMessagePolicy?: string;
    /**
     * Whether this container should allocate a TTY for itself.
     */
    readonly tty?: boolean;
    /**
     * Container's working directory.
     *
     * If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
     */
    readonly workingDir?: string;
    /**
     * env block.
     */
    readonly env?: ReplicationControllerSpecTemplateContainerEnv[];
    /**
     * env_from block.
     */
    readonly envFrom?: ReplicationControllerSpecTemplateContainerEnvFrom[];
    /**
     * lifecycle block.
     */
    readonly lifecycle?: ReplicationControllerSpecTemplateContainerLifecycle[];
    /**
     * liveness_probe block.
     */
    readonly livenessProbe?: ReplicationControllerSpecTemplateContainerLivenessProbe[];
    /**
     * port block.
     */
    readonly port?: ReplicationControllerSpecTemplateContainerPort[];
    /**
     * readiness_probe block.
     */
    readonly readinessProbe?: ReplicationControllerSpecTemplateContainerReadinessProbe[];
    /**
     * resources block.
     */
    readonly resources?: ReplicationControllerSpecTemplateContainerResources[];
    /**
     * security_context block.
     */
    readonly securityContext?: ReplicationControllerSpecTemplateContainerSecurityContext[];
    /**
     * startup_probe block.
     */
    readonly startupProbe?: ReplicationControllerSpecTemplateContainerStartupProbe[];
    /**
     * volume_mount block.
     */
    readonly volumeMount?: ReplicationControllerSpecTemplateContainerVolumeMount[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateDnsConfigOption {
    /**
     * Name of the option.
     */
    readonly name: string;
    /**
     * Value of the option.
     *
     * Optional: Defaults to empty.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateDnsConfig {
    /**
     * A list of DNS name server IP addresses.
     *
     * This will be appended to the base nameservers generated from DNSPolicy. Duplicated nameservers will be removed.
     */
    readonly nameservers?: string[];
    /**
     * A list of DNS search domains for host-name lookup.
     *
     * This will be appended to the base search paths generated from DNSPolicy. Duplicated search paths will be removed.
     */
    readonly searches?: string[];
    /**
     * option block.
     */
    readonly option?: ReplicationControllerSpecTemplateDnsConfigOption[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateHostAliases {
    /**
     * Hostnames for the IP address.
     */
    readonly hostnames: string[];
    /**
     * IP address of the host file entry.
     */
    readonly ip: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateImagePullSecrets {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerEnvValueFromConfigMapKeyRef {
    /**
     * The key to select.
     */
    readonly key?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Specify whether the ConfigMap or its key must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerEnvValueFromFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     */
    readonly fieldPath?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerEnvValueFromResourceFieldRef {
    /**
     *
     */
    readonly containerName?: string;
    /**
     * Resource to select.
     */
    readonly resource: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerEnvValueFromSecretKeyRef {
    /**
     * The key of the secret to select from.
     *
     * Must be a valid secret key.
     */
    readonly key?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Specify whether the Secret or its key must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerEnvValueFrom {
    /**
     * config_map_key_ref block.
     */
    readonly configMapKeyRef?: ReplicationControllerSpecTemplateInitContainerEnvValueFromConfigMapKeyRef[];
    /**
     * field_ref block.
     */
    readonly fieldRef?: ReplicationControllerSpecTemplateInitContainerEnvValueFromFieldRef[];
    /**
     * resource_field_ref block.
     */
    readonly resourceFieldRef?: ReplicationControllerSpecTemplateInitContainerEnvValueFromResourceFieldRef[];
    /**
     * secret_key_ref block.
     */
    readonly secretKeyRef?: ReplicationControllerSpecTemplateInitContainerEnvValueFromSecretKeyRef[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerEnv {
    /**
     * Name of the environment variable.
     *
     * Must be a C_IDENTIFIER
     */
    readonly name: string;
    /**
     * Variable references $(VAR_NAME) are expanded using the previous defined environment variables in the container and any service environment variables.
     *
     * If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
     */
    readonly value?: string;
    /**
     * value_from block.
     */
    readonly valueFrom?: ReplicationControllerSpecTemplateInitContainerEnvValueFrom[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerEnvFromConfigMapRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name: string;
    /**
     * Specify whether the ConfigMap must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerEnvFromSecretRef {
    /**
     * Name of the referent.
     *
     * More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
     */
    readonly name: string;
    /**
     * Specify whether the Secret must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerEnvFrom {
    /**
     * An optional identifer to prepend to each key in the ConfigMap.
     *
     * Must be a C_IDENTIFIER.
     */
    readonly prefix?: string;
    /**
     * config_map_ref block.
     */
    readonly configMapRef?: ReplicationControllerSpecTemplateInitContainerEnvFromConfigMapRef[];
    /**
     * secret_ref block.
     */
    readonly secretRef?: ReplicationControllerSpecTemplateInitContainerEnvFromSecretRef[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerLifecyclePostStartExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerLifecyclePostStartHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerLifecyclePostStartHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: ReplicationControllerSpecTemplateInitContainerLifecyclePostStartHttpGetHttpHeader[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerLifecyclePostStartTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerLifecyclePostStart {
    /**
     * exec block.
     */
    readonly exec?: ReplicationControllerSpecTemplateInitContainerLifecyclePostStartExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: ReplicationControllerSpecTemplateInitContainerLifecyclePostStartHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: ReplicationControllerSpecTemplateInitContainerLifecyclePostStartTcpSocket[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerLifecyclePreStopExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerLifecyclePreStopHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerLifecyclePreStopHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: ReplicationControllerSpecTemplateInitContainerLifecyclePreStopHttpGetHttpHeader[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerLifecyclePreStopTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerLifecyclePreStop {
    /**
     * exec block.
     */
    readonly exec?: ReplicationControllerSpecTemplateInitContainerLifecyclePreStopExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: ReplicationControllerSpecTemplateInitContainerLifecyclePreStopHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: ReplicationControllerSpecTemplateInitContainerLifecyclePreStopTcpSocket[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerLifecycle {
    /**
     * post_start block.
     */
    readonly postStart?: ReplicationControllerSpecTemplateInitContainerLifecyclePostStart[];
    /**
     * pre_stop block.
     */
    readonly preStop?: ReplicationControllerSpecTemplateInitContainerLifecyclePreStop[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerLivenessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerLivenessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerLivenessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: ReplicationControllerSpecTemplateInitContainerLivenessProbeHttpGetHttpHeader[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerLivenessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerLivenessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     */
    readonly exec?: ReplicationControllerSpecTemplateInitContainerLivenessProbeExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: ReplicationControllerSpecTemplateInitContainerLivenessProbeHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: ReplicationControllerSpecTemplateInitContainerLivenessProbeTcpSocket[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerPort {
    /**
     * Number of port to expose on the pod's IP address.
     *
     * This must be a valid port number, 0 < x < 65536.
     */
    readonly containerPort: number;
    /**
     * What host IP to bind the external port to.
     */
    readonly hostIp?: string;
    /**
     * Number of port to expose on the host.
     *
     * If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
     */
    readonly hostPort?: number;
    /**
     * If specified, this must be an IANA_SVC_NAME and unique within the pod.
     *
     * Each named port in a pod must have a unique name. Name for the port that can be referred to by services
     */
    readonly name?: string;
    /**
     * Protocol for port.
     *
     * Must be UDP or TCP. Defaults to "TCP".
     */
    readonly protocol?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerReadinessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerReadinessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerReadinessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: ReplicationControllerSpecTemplateInitContainerReadinessProbeHttpGetHttpHeader[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerReadinessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerReadinessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     */
    readonly exec?: ReplicationControllerSpecTemplateInitContainerReadinessProbeExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: ReplicationControllerSpecTemplateInitContainerReadinessProbeHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: ReplicationControllerSpecTemplateInitContainerReadinessProbeTcpSocket[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerResourcesLimits {
    /**
     *
     */
    readonly cpu?: string;
    /**
     *
     */
    readonly memory?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerResourcesRequests {
    /**
     *
     */
    readonly cpu?: string;
    /**
     *
     */
    readonly memory?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerResources {
    /**
     * limits block.
     */
    readonly limits?: ReplicationControllerSpecTemplateInitContainerResourcesLimits[];
    /**
     * requests block.
     */
    readonly requests?: ReplicationControllerSpecTemplateInitContainerResourcesRequests[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerSecurityContextCapabilities {
    /**
     * Added capabilities.
     */
    readonly add?: string[];
    /**
     * Removed capabilities.
     */
    readonly drop?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     */
    readonly user?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerSecurityContext {
    /**
     * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process.
     *
     * This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN
     */
    readonly allowPrivilegeEscalation?: boolean;
    /**
     * Run container in privileged mode.
     *
     * Processes in privileged containers are essentially equivalent to root on the host. Defaults to false.
     */
    readonly privileged?: boolean;
    /**
     * Whether this container has a read-only root filesystem.
     *
     * Default is false.
     */
    readonly readOnlyRootFilesystem?: boolean;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     */
    readonly runAsGroup?: number;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     */
    readonly runAsNonRoot?: boolean;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     */
    readonly runAsUser?: number;
    /**
     * capabilities block.
     */
    readonly capabilities?: ReplicationControllerSpecTemplateInitContainerSecurityContextCapabilities[];
    /**
     * se_linux_options block.
     */
    readonly seLinuxOptions?: ReplicationControllerSpecTemplateInitContainerSecurityContextSeLinuxOptions[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerStartupProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerStartupProbeHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerStartupProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: ReplicationControllerSpecTemplateInitContainerStartupProbeHttpGetHttpHeader[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerStartupProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerStartupProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     */
    readonly exec?: ReplicationControllerSpecTemplateInitContainerStartupProbeExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: ReplicationControllerSpecTemplateInitContainerStartupProbeHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: ReplicationControllerSpecTemplateInitContainerStartupProbeTcpSocket[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainerVolumeMount {
    /**
     * Path within the container at which the volume should be mounted.
     *
     * Must not contain ':'.
     */
    readonly mountPath: string;
    /**
     * Mount propagation mode.
     *
     * mount_propagation determines how mounts are propagated from the host to container and the other way around. Valid values are None (default), HostToContainer and Bidirectional.
     */
    readonly mountPropagation?: string;
    /**
     * This must match the Name of a Volume.
     */
    readonly name: string;
    /**
     * Mounted read-only if true, read-write otherwise (false or unspecified).
     *
     * Defaults to false.
     */
    readonly readOnly?: boolean;
    /**
     * Path within the volume from which the container's volume should be mounted.
     *
     * Defaults to "" (volume's root).
     */
    readonly subPath?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateInitContainer {
    /**
     * Arguments to the entrypoint.
     *
     * The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     */
    readonly args?: string[];
    /**
     * Entrypoint array.
     *
     * Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     */
    readonly command?: string[];
    /**
     * Docker image name.
     *
     * More info: http://kubernetes.io/docs/user-guide/images
     */
    readonly image?: string;
    /**
     * Image pull policy.
     *
     * One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/images#updating-images
     */
    readonly imagePullPolicy?: string;
    /**
     * Name of the container specified as a DNS_LABEL.
     *
     * Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
     */
    readonly name: string;
    /**
     * Whether this container should allocate a buffer for stdin in the container runtime.
     *
     * If this is not set, reads from stdin in the container will always result in EOF.
     */
    readonly stdin?: boolean;
    /**
     * Whether the container runtime should close the stdin channel after it has been opened by a single attach.
     *
     * When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF.
     */
    readonly stdinOnce?: boolean;
    /**
     * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem.
     *
     * Message written is intended to be brief final status, such as an assertion failure message. Defaults to /dev/termination-log. Cannot be updated.
     */
    readonly terminationMessagePath?: string;
    /**
     * Optional: Indicate how the termination message should be populated.
     *
     * File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
     */
    readonly terminationMessagePolicy?: string;
    /**
     * Whether this container should allocate a TTY for itself.
     */
    readonly tty?: boolean;
    /**
     * Container's working directory.
     *
     * If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
     */
    readonly workingDir?: string;
    /**
     * env block.
     */
    readonly env?: ReplicationControllerSpecTemplateInitContainerEnv[];
    /**
     * env_from block.
     */
    readonly envFrom?: ReplicationControllerSpecTemplateInitContainerEnvFrom[];
    /**
     * lifecycle block.
     */
    readonly lifecycle?: ReplicationControllerSpecTemplateInitContainerLifecycle[];
    /**
     * liveness_probe block.
     */
    readonly livenessProbe?: ReplicationControllerSpecTemplateInitContainerLivenessProbe[];
    /**
     * port block.
     */
    readonly port?: ReplicationControllerSpecTemplateInitContainerPort[];
    /**
     * readiness_probe block.
     */
    readonly readinessProbe?: ReplicationControllerSpecTemplateInitContainerReadinessProbe[];
    /**
     * resources block.
     */
    readonly resources?: ReplicationControllerSpecTemplateInitContainerResources[];
    /**
     * security_context block.
     */
    readonly securityContext?: ReplicationControllerSpecTemplateInitContainerSecurityContext[];
    /**
     * startup_probe block.
     */
    readonly startupProbe?: ReplicationControllerSpecTemplateInitContainerStartupProbe[];
    /**
     * volume_mount block.
     */
    readonly volumeMount?: ReplicationControllerSpecTemplateInitContainerVolumeMount[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateMetadata {
    /**
     * An unstructured key value map stored with the replication controller's template that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the replication controller's template.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the replication controller's template, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the replication controller's template must be unique.
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     */
    readonly user?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSecurityContextSysctl {
    /**
     * Name of a property to set.
     */
    readonly name: string;
    /**
     * Value of a property to set.
     */
    readonly value: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSecurityContext {
    /**
     * A special supplemental group that applies to all containers in a pod.
     *
     * Some volume types allow the Kubelet to change the ownership of that volume to be owned by the pod: 1. The owning GID will be the FSGroup 2. The setgid bit is set (new files created in the volume will be owned by FSGroup) 3. The permission bits are OR'd with rw-rw---- If unset, the Kubelet will not modify the ownership and permissions of any volume.
     */
    readonly fsGroup?: number;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.
     */
    readonly runAsGroup?: number;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     */
    readonly runAsNonRoot?: boolean;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.
     */
    readonly runAsUser?: number;
    /**
     * A list of groups applied to the first process run in each container, in addition to the container's primary GID.
     *
     * If unspecified, no groups will be added to any container.
     */
    readonly supplementalGroups?: number[];
    /**
     * se_linux_options block.
     */
    readonly seLinuxOptions?: ReplicationControllerSpecTemplateSecurityContextSeLinuxOptions[];
    /**
     * sysctl block.
     */
    readonly sysctl?: ReplicationControllerSpecTemplateSecurityContextSysctl[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions {
    /**
     * The label key that the selector applies to.
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to a set of values.
     *
     * Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
     */
    readonly operator?: string;
    /**
     * Values is an array of string values.
     *
     * If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference {
    /**
     * match_expressions block.
     */
    readonly matchExpressions?: ReplicationControllerSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight is in the range 1-100.
     */
    readonly weight: number;
    /**
     * preference block.
     */
    readonly preference: ReplicationControllerSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions {
    /**
     * The label key that the selector applies to.
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to a set of values.
     *
     * Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
     */
    readonly operator?: string;
    /**
     * Values is an array of string values.
     *
     * If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm {
    /**
     * match_expressions block.
     */
    readonly matchExpressions?: ReplicationControllerSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * node_selector_term block.
     */
    readonly nodeSelectorTerm?: ReplicationControllerSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityNodeAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: ReplicationControllerSpecTemplateSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: ReplicationControllerSpecTemplateSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     */
    readonly matchExpressions?: ReplicationControllerSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against);
     *
     * null or empty list means 'this pod's namespace'
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     */
    readonly labelSelector?: ReplicationControllerSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
     */
    readonly weight: number;
    /**
     * pod_affinity_term block.
     */
    readonly podAffinityTerm: ReplicationControllerSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     */
    readonly matchExpressions?: ReplicationControllerSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against);
     *
     * null or empty list means 'this pod's namespace'
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     */
    readonly labelSelector?: ReplicationControllerSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityPodAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: ReplicationControllerSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: ReplicationControllerSpecTemplateSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     */
    readonly matchExpressions?: ReplicationControllerSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against);
     *
     * null or empty list means 'this pod's namespace'
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     */
    readonly labelSelector?: ReplicationControllerSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
     */
    readonly weight: number;
    /**
     * pod_affinity_term block.
     */
    readonly podAffinityTerm: ReplicationControllerSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     */
    readonly values?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     */
    readonly matchExpressions?: ReplicationControllerSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against);
     *
     * null or empty list means 'this pod's namespace'
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     */
    readonly labelSelector?: ReplicationControllerSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinityPodAntiAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: ReplicationControllerSpecTemplateSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: ReplicationControllerSpecTemplateSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecAffinity {
    /**
     * node_affinity block.
     */
    readonly nodeAffinity?: ReplicationControllerSpecTemplateSpecAffinityNodeAffinity[];
    /**
     * pod_affinity block.
     */
    readonly podAffinity?: ReplicationControllerSpecTemplateSpecAffinityPodAffinity[];
    /**
     * pod_anti_affinity block.
     */
    readonly podAntiAffinity?: ReplicationControllerSpecTemplateSpecAffinityPodAntiAffinity[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerEnvValueFromConfigMapKeyRef {
    /**
     * The key to select.
     */
    readonly key?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Specify whether the ConfigMap or its key must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerEnvValueFromFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     */
    readonly fieldPath?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerEnvValueFromResourceFieldRef {
    /**
     *
     */
    readonly containerName?: string;
    /**
     * Resource to select.
     */
    readonly resource: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerEnvValueFromSecretKeyRef {
    /**
     * The key of the secret to select from.
     *
     * Must be a valid secret key.
     */
    readonly key?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Specify whether the Secret or its key must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerEnvValueFrom {
    /**
     * config_map_key_ref block.
     */
    readonly configMapKeyRef?: ReplicationControllerSpecTemplateSpecContainerEnvValueFromConfigMapKeyRef[];
    /**
     * field_ref block.
     */
    readonly fieldRef?: ReplicationControllerSpecTemplateSpecContainerEnvValueFromFieldRef[];
    /**
     * resource_field_ref block.
     */
    readonly resourceFieldRef?: ReplicationControllerSpecTemplateSpecContainerEnvValueFromResourceFieldRef[];
    /**
     * secret_key_ref block.
     */
    readonly secretKeyRef?: ReplicationControllerSpecTemplateSpecContainerEnvValueFromSecretKeyRef[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerEnv {
    /**
     * Name of the environment variable.
     *
     * Must be a C_IDENTIFIER
     */
    readonly name: string;
    /**
     * Variable references $(VAR_NAME) are expanded using the previous defined environment variables in the container and any service environment variables.
     *
     * If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
     */
    readonly value?: string;
    /**
     * value_from block.
     */
    readonly valueFrom?: ReplicationControllerSpecTemplateSpecContainerEnvValueFrom[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerEnvFromConfigMapRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name: string;
    /**
     * Specify whether the ConfigMap must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerEnvFromSecretRef {
    /**
     * Name of the referent.
     *
     * More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
     */
    readonly name: string;
    /**
     * Specify whether the Secret must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerEnvFrom {
    /**
     * An optional identifer to prepend to each key in the ConfigMap.
     *
     * Must be a C_IDENTIFIER.
     */
    readonly prefix?: string;
    /**
     * config_map_ref block.
     */
    readonly configMapRef?: ReplicationControllerSpecTemplateSpecContainerEnvFromConfigMapRef[];
    /**
     * secret_ref block.
     */
    readonly secretRef?: ReplicationControllerSpecTemplateSpecContainerEnvFromSecretRef[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerLifecyclePostStartExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerLifecyclePostStartHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: ReplicationControllerSpecTemplateSpecContainerLifecyclePostStartHttpGetHttpHeader[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerLifecyclePostStartTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerLifecyclePostStart {
    /**
     * exec block.
     */
    readonly exec?: ReplicationControllerSpecTemplateSpecContainerLifecyclePostStartExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: ReplicationControllerSpecTemplateSpecContainerLifecyclePostStartHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: ReplicationControllerSpecTemplateSpecContainerLifecyclePostStartTcpSocket[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerLifecyclePreStopExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerLifecyclePreStopHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: ReplicationControllerSpecTemplateSpecContainerLifecyclePreStopHttpGetHttpHeader[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerLifecyclePreStopTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerLifecyclePreStop {
    /**
     * exec block.
     */
    readonly exec?: ReplicationControllerSpecTemplateSpecContainerLifecyclePreStopExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: ReplicationControllerSpecTemplateSpecContainerLifecyclePreStopHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: ReplicationControllerSpecTemplateSpecContainerLifecyclePreStopTcpSocket[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerLifecycle {
    /**
     * post_start block.
     */
    readonly postStart?: ReplicationControllerSpecTemplateSpecContainerLifecyclePostStart[];
    /**
     * pre_stop block.
     */
    readonly preStop?: ReplicationControllerSpecTemplateSpecContainerLifecyclePreStop[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerLivenessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerLivenessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: ReplicationControllerSpecTemplateSpecContainerLivenessProbeHttpGetHttpHeader[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerLivenessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerLivenessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     */
    readonly exec?: ReplicationControllerSpecTemplateSpecContainerLivenessProbeExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: ReplicationControllerSpecTemplateSpecContainerLivenessProbeHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: ReplicationControllerSpecTemplateSpecContainerLivenessProbeTcpSocket[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerPort {
    /**
     * Number of port to expose on the pod's IP address.
     *
     * This must be a valid port number, 0 < x < 65536.
     */
    readonly containerPort: number;
    /**
     * What host IP to bind the external port to.
     */
    readonly hostIp?: string;
    /**
     * Number of port to expose on the host.
     *
     * If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
     */
    readonly hostPort?: number;
    /**
     * If specified, this must be an IANA_SVC_NAME and unique within the pod.
     *
     * Each named port in a pod must have a unique name. Name for the port that can be referred to by services
     */
    readonly name?: string;
    /**
     * Protocol for port.
     *
     * Must be UDP or TCP. Defaults to "TCP".
     */
    readonly protocol?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerReadinessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerReadinessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: ReplicationControllerSpecTemplateSpecContainerReadinessProbeHttpGetHttpHeader[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerReadinessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerReadinessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     */
    readonly exec?: ReplicationControllerSpecTemplateSpecContainerReadinessProbeExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: ReplicationControllerSpecTemplateSpecContainerReadinessProbeHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: ReplicationControllerSpecTemplateSpecContainerReadinessProbeTcpSocket[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerResourcesLimits {
    /**
     *
     */
    readonly cpu?: string;
    /**
     *
     */
    readonly memory?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerResourcesRequests {
    /**
     *
     */
    readonly cpu?: string;
    /**
     *
     */
    readonly memory?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerResources {
    /**
     * limits block.
     */
    readonly limits?: ReplicationControllerSpecTemplateSpecContainerResourcesLimits[];
    /**
     * requests block.
     */
    readonly requests?: ReplicationControllerSpecTemplateSpecContainerResourcesRequests[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerSecurityContextCapabilities {
    /**
     * Added capabilities.
     */
    readonly add?: string[];
    /**
     * Removed capabilities.
     */
    readonly drop?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     */
    readonly user?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerSecurityContext {
    /**
     * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process.
     *
     * This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN
     */
    readonly allowPrivilegeEscalation?: boolean;
    /**
     * Run container in privileged mode.
     *
     * Processes in privileged containers are essentially equivalent to root on the host. Defaults to false.
     */
    readonly privileged?: boolean;
    /**
     * Whether this container has a read-only root filesystem.
     *
     * Default is false.
     */
    readonly readOnlyRootFilesystem?: boolean;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     */
    readonly runAsGroup?: number;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     */
    readonly runAsNonRoot?: boolean;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     */
    readonly runAsUser?: number;
    /**
     * capabilities block.
     */
    readonly capabilities?: ReplicationControllerSpecTemplateSpecContainerSecurityContextCapabilities[];
    /**
     * se_linux_options block.
     */
    readonly seLinuxOptions?: ReplicationControllerSpecTemplateSpecContainerSecurityContextSeLinuxOptions[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerStartupProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerStartupProbeHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerStartupProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: ReplicationControllerSpecTemplateSpecContainerStartupProbeHttpGetHttpHeader[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerStartupProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerStartupProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     */
    readonly exec?: ReplicationControllerSpecTemplateSpecContainerStartupProbeExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: ReplicationControllerSpecTemplateSpecContainerStartupProbeHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: ReplicationControllerSpecTemplateSpecContainerStartupProbeTcpSocket[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainerVolumeMount {
    /**
     * Path within the container at which the volume should be mounted.
     *
     * Must not contain ':'.
     */
    readonly mountPath: string;
    /**
     * Mount propagation mode.
     *
     * mount_propagation determines how mounts are propagated from the host to container and the other way around. Valid values are None (default), HostToContainer and Bidirectional.
     */
    readonly mountPropagation?: string;
    /**
     * This must match the Name of a Volume.
     */
    readonly name: string;
    /**
     * Mounted read-only if true, read-write otherwise (false or unspecified).
     *
     * Defaults to false.
     */
    readonly readOnly?: boolean;
    /**
     * Path within the volume from which the container's volume should be mounted.
     *
     * Defaults to "" (volume's root).
     */
    readonly subPath?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecContainer {
    /**
     * Arguments to the entrypoint.
     *
     * The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     */
    readonly args?: string[];
    /**
     * Entrypoint array.
     *
     * Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     */
    readonly command?: string[];
    /**
     * Docker image name.
     *
     * More info: http://kubernetes.io/docs/user-guide/images
     */
    readonly image?: string;
    /**
     * Image pull policy.
     *
     * One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/images#updating-images
     */
    readonly imagePullPolicy?: string;
    /**
     * Name of the container specified as a DNS_LABEL.
     *
     * Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
     */
    readonly name: string;
    /**
     * Whether this container should allocate a buffer for stdin in the container runtime.
     *
     * If this is not set, reads from stdin in the container will always result in EOF.
     */
    readonly stdin?: boolean;
    /**
     * Whether the container runtime should close the stdin channel after it has been opened by a single attach.
     *
     * When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF.
     */
    readonly stdinOnce?: boolean;
    /**
     * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem.
     *
     * Message written is intended to be brief final status, such as an assertion failure message. Defaults to /dev/termination-log. Cannot be updated.
     */
    readonly terminationMessagePath?: string;
    /**
     * Optional: Indicate how the termination message should be populated.
     *
     * File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
     */
    readonly terminationMessagePolicy?: string;
    /**
     * Whether this container should allocate a TTY for itself.
     */
    readonly tty?: boolean;
    /**
     * Container's working directory.
     *
     * If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
     */
    readonly workingDir?: string;
    /**
     * env block.
     */
    readonly env?: ReplicationControllerSpecTemplateSpecContainerEnv[];
    /**
     * env_from block.
     */
    readonly envFrom?: ReplicationControllerSpecTemplateSpecContainerEnvFrom[];
    /**
     * lifecycle block.
     */
    readonly lifecycle?: ReplicationControllerSpecTemplateSpecContainerLifecycle[];
    /**
     * liveness_probe block.
     */
    readonly livenessProbe?: ReplicationControllerSpecTemplateSpecContainerLivenessProbe[];
    /**
     * port block.
     */
    readonly port?: ReplicationControllerSpecTemplateSpecContainerPort[];
    /**
     * readiness_probe block.
     */
    readonly readinessProbe?: ReplicationControllerSpecTemplateSpecContainerReadinessProbe[];
    /**
     * resources block.
     */
    readonly resources?: ReplicationControllerSpecTemplateSpecContainerResources[];
    /**
     * security_context block.
     */
    readonly securityContext?: ReplicationControllerSpecTemplateSpecContainerSecurityContext[];
    /**
     * startup_probe block.
     */
    readonly startupProbe?: ReplicationControllerSpecTemplateSpecContainerStartupProbe[];
    /**
     * volume_mount block.
     */
    readonly volumeMount?: ReplicationControllerSpecTemplateSpecContainerVolumeMount[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecDnsConfigOption {
    /**
     * Name of the option.
     */
    readonly name: string;
    /**
     * Value of the option.
     *
     * Optional: Defaults to empty.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecDnsConfig {
    /**
     * A list of DNS name server IP addresses.
     *
     * This will be appended to the base nameservers generated from DNSPolicy. Duplicated nameservers will be removed.
     */
    readonly nameservers?: string[];
    /**
     * A list of DNS search domains for host-name lookup.
     *
     * This will be appended to the base search paths generated from DNSPolicy. Duplicated search paths will be removed.
     */
    readonly searches?: string[];
    /**
     * option block.
     */
    readonly option?: ReplicationControllerSpecTemplateSpecDnsConfigOption[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecHostAliases {
    /**
     * Hostnames for the IP address.
     */
    readonly hostnames: string[];
    /**
     * IP address of the host file entry.
     */
    readonly ip: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecImagePullSecrets {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef {
    /**
     * The key to select.
     */
    readonly key?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Specify whether the ConfigMap or its key must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerEnvValueFromFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     */
    readonly fieldPath?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerEnvValueFromResourceFieldRef {
    /**
     *
     */
    readonly containerName?: string;
    /**
     * Resource to select.
     */
    readonly resource: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerEnvValueFromSecretKeyRef {
    /**
     * The key of the secret to select from.
     *
     * Must be a valid secret key.
     */
    readonly key?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Specify whether the Secret or its key must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerEnvValueFrom {
    /**
     * config_map_key_ref block.
     */
    readonly configMapKeyRef?: ReplicationControllerSpecTemplateSpecInitContainerEnvValueFromConfigMapKeyRef[];
    /**
     * field_ref block.
     */
    readonly fieldRef?: ReplicationControllerSpecTemplateSpecInitContainerEnvValueFromFieldRef[];
    /**
     * resource_field_ref block.
     */
    readonly resourceFieldRef?: ReplicationControllerSpecTemplateSpecInitContainerEnvValueFromResourceFieldRef[];
    /**
     * secret_key_ref block.
     */
    readonly secretKeyRef?: ReplicationControllerSpecTemplateSpecInitContainerEnvValueFromSecretKeyRef[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerEnv {
    /**
     * Name of the environment variable.
     *
     * Must be a C_IDENTIFIER
     */
    readonly name: string;
    /**
     * Variable references $(VAR_NAME) are expanded using the previous defined environment variables in the container and any service environment variables.
     *
     * If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
     */
    readonly value?: string;
    /**
     * value_from block.
     */
    readonly valueFrom?: ReplicationControllerSpecTemplateSpecInitContainerEnvValueFrom[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerEnvFromConfigMapRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name: string;
    /**
     * Specify whether the ConfigMap must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerEnvFromSecretRef {
    /**
     * Name of the referent.
     *
     * More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
     */
    readonly name: string;
    /**
     * Specify whether the Secret must be defined.
     */
    readonly optional?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerEnvFrom {
    /**
     * An optional identifer to prepend to each key in the ConfigMap.
     *
     * Must be a C_IDENTIFIER.
     */
    readonly prefix?: string;
    /**
     * config_map_ref block.
     */
    readonly configMapRef?: ReplicationControllerSpecTemplateSpecInitContainerEnvFromConfigMapRef[];
    /**
     * secret_ref block.
     */
    readonly secretRef?: ReplicationControllerSpecTemplateSpecInitContainerEnvFromSecretRef[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerLifecyclePostStartExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerLifecyclePostStartHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: ReplicationControllerSpecTemplateSpecInitContainerLifecyclePostStartHttpGetHttpHeader[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerLifecyclePostStartTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerLifecyclePostStart {
    /**
     * exec block.
     */
    readonly exec?: ReplicationControllerSpecTemplateSpecInitContainerLifecyclePostStartExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: ReplicationControllerSpecTemplateSpecInitContainerLifecyclePostStartHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: ReplicationControllerSpecTemplateSpecInitContainerLifecyclePostStartTcpSocket[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerLifecyclePreStopExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerLifecyclePreStopHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: ReplicationControllerSpecTemplateSpecInitContainerLifecyclePreStopHttpGetHttpHeader[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerLifecyclePreStopTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerLifecyclePreStop {
    /**
     * exec block.
     */
    readonly exec?: ReplicationControllerSpecTemplateSpecInitContainerLifecyclePreStopExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: ReplicationControllerSpecTemplateSpecInitContainerLifecyclePreStopHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: ReplicationControllerSpecTemplateSpecInitContainerLifecyclePreStopTcpSocket[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerLifecycle {
    /**
     * post_start block.
     */
    readonly postStart?: ReplicationControllerSpecTemplateSpecInitContainerLifecyclePostStart[];
    /**
     * pre_stop block.
     */
    readonly preStop?: ReplicationControllerSpecTemplateSpecInitContainerLifecyclePreStop[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerLivenessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerLivenessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: ReplicationControllerSpecTemplateSpecInitContainerLivenessProbeHttpGetHttpHeader[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerLivenessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerLivenessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     */
    readonly exec?: ReplicationControllerSpecTemplateSpecInitContainerLivenessProbeExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: ReplicationControllerSpecTemplateSpecInitContainerLivenessProbeHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: ReplicationControllerSpecTemplateSpecInitContainerLivenessProbeTcpSocket[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerPort {
    /**
     * Number of port to expose on the pod's IP address.
     *
     * This must be a valid port number, 0 < x < 65536.
     */
    readonly containerPort: number;
    /**
     * What host IP to bind the external port to.
     */
    readonly hostIp?: string;
    /**
     * Number of port to expose on the host.
     *
     * If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
     */
    readonly hostPort?: number;
    /**
     * If specified, this must be an IANA_SVC_NAME and unique within the pod.
     *
     * Each named port in a pod must have a unique name. Name for the port that can be referred to by services
     */
    readonly name?: string;
    /**
     * Protocol for port.
     *
     * Must be UDP or TCP. Defaults to "TCP".
     */
    readonly protocol?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerReadinessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerReadinessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: ReplicationControllerSpecTemplateSpecInitContainerReadinessProbeHttpGetHttpHeader[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerReadinessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerReadinessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     */
    readonly exec?: ReplicationControllerSpecTemplateSpecInitContainerReadinessProbeExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: ReplicationControllerSpecTemplateSpecInitContainerReadinessProbeHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: ReplicationControllerSpecTemplateSpecInitContainerReadinessProbeTcpSocket[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerResourcesLimits {
    /**
     *
     */
    readonly cpu?: string;
    /**
     *
     */
    readonly memory?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerResourcesRequests {
    /**
     *
     */
    readonly cpu?: string;
    /**
     *
     */
    readonly memory?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerResources {
    /**
     * limits block.
     */
    readonly limits?: ReplicationControllerSpecTemplateSpecInitContainerResourcesLimits[];
    /**
     * requests block.
     */
    readonly requests?: ReplicationControllerSpecTemplateSpecInitContainerResourcesRequests[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerSecurityContextCapabilities {
    /**
     * Added capabilities.
     */
    readonly add?: string[];
    /**
     * Removed capabilities.
     */
    readonly drop?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     */
    readonly user?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerSecurityContext {
    /**
     * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process.
     *
     * This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN
     */
    readonly allowPrivilegeEscalation?: boolean;
    /**
     * Run container in privileged mode.
     *
     * Processes in privileged containers are essentially equivalent to root on the host. Defaults to false.
     */
    readonly privileged?: boolean;
    /**
     * Whether this container has a read-only root filesystem.
     *
     * Default is false.
     */
    readonly readOnlyRootFilesystem?: boolean;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     */
    readonly runAsGroup?: number;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     */
    readonly runAsNonRoot?: boolean;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     */
    readonly runAsUser?: number;
    /**
     * capabilities block.
     */
    readonly capabilities?: ReplicationControllerSpecTemplateSpecInitContainerSecurityContextCapabilities[];
    /**
     * se_linux_options block.
     */
    readonly seLinuxOptions?: ReplicationControllerSpecTemplateSpecInitContainerSecurityContextSeLinuxOptions[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerStartupProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     */
    readonly command?: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader {
    /**
     * The header field name.
     */
    readonly name?: string;
    /**
     * The header field value.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerStartupProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP.
     *
     * You probably want to set "Host" in httpHeaders instead.
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     */
    readonly scheme?: string;
    /**
     * http_header block.
     */
    readonly httpHeader?: ReplicationControllerSpecTemplateSpecInitContainerStartupProbeHttpGetHttpHeader[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerStartupProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     */
    readonly port: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerStartupProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out.
     *
     * More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     */
    readonly exec?: ReplicationControllerSpecTemplateSpecInitContainerStartupProbeExec[];
    /**
     * http_get block.
     */
    readonly httpGet?: ReplicationControllerSpecTemplateSpecInitContainerStartupProbeHttpGet[];
    /**
     * tcp_socket block.
     */
    readonly tcpSocket?: ReplicationControllerSpecTemplateSpecInitContainerStartupProbeTcpSocket[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainerVolumeMount {
    /**
     * Path within the container at which the volume should be mounted.
     *
     * Must not contain ':'.
     */
    readonly mountPath: string;
    /**
     * Mount propagation mode.
     *
     * mount_propagation determines how mounts are propagated from the host to container and the other way around. Valid values are None (default), HostToContainer and Bidirectional.
     */
    readonly mountPropagation?: string;
    /**
     * This must match the Name of a Volume.
     */
    readonly name: string;
    /**
     * Mounted read-only if true, read-write otherwise (false or unspecified).
     *
     * Defaults to false.
     */
    readonly readOnly?: boolean;
    /**
     * Path within the volume from which the container's volume should be mounted.
     *
     * Defaults to "" (volume's root).
     */
    readonly subPath?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecInitContainer {
    /**
     * Arguments to the entrypoint.
     *
     * The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     */
    readonly args?: string[];
    /**
     * Entrypoint array.
     *
     * Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     */
    readonly command?: string[];
    /**
     * Docker image name.
     *
     * More info: http://kubernetes.io/docs/user-guide/images
     */
    readonly image?: string;
    /**
     * Image pull policy.
     *
     * One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/images#updating-images
     */
    readonly imagePullPolicy?: string;
    /**
     * Name of the container specified as a DNS_LABEL.
     *
     * Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
     */
    readonly name: string;
    /**
     * Whether this container should allocate a buffer for stdin in the container runtime.
     *
     * If this is not set, reads from stdin in the container will always result in EOF.
     */
    readonly stdin?: boolean;
    /**
     * Whether the container runtime should close the stdin channel after it has been opened by a single attach.
     *
     * When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF.
     */
    readonly stdinOnce?: boolean;
    /**
     * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem.
     *
     * Message written is intended to be brief final status, such as an assertion failure message. Defaults to /dev/termination-log. Cannot be updated.
     */
    readonly terminationMessagePath?: string;
    /**
     * Optional: Indicate how the termination message should be populated.
     *
     * File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
     */
    readonly terminationMessagePolicy?: string;
    /**
     * Whether this container should allocate a TTY for itself.
     */
    readonly tty?: boolean;
    /**
     * Container's working directory.
     *
     * If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
     */
    readonly workingDir?: string;
    /**
     * env block.
     */
    readonly env?: ReplicationControllerSpecTemplateSpecInitContainerEnv[];
    /**
     * env_from block.
     */
    readonly envFrom?: ReplicationControllerSpecTemplateSpecInitContainerEnvFrom[];
    /**
     * lifecycle block.
     */
    readonly lifecycle?: ReplicationControllerSpecTemplateSpecInitContainerLifecycle[];
    /**
     * liveness_probe block.
     */
    readonly livenessProbe?: ReplicationControllerSpecTemplateSpecInitContainerLivenessProbe[];
    /**
     * port block.
     */
    readonly port?: ReplicationControllerSpecTemplateSpecInitContainerPort[];
    /**
     * readiness_probe block.
     */
    readonly readinessProbe?: ReplicationControllerSpecTemplateSpecInitContainerReadinessProbe[];
    /**
     * resources block.
     */
    readonly resources?: ReplicationControllerSpecTemplateSpecInitContainerResources[];
    /**
     * security_context block.
     */
    readonly securityContext?: ReplicationControllerSpecTemplateSpecInitContainerSecurityContext[];
    /**
     * startup_probe block.
     */
    readonly startupProbe?: ReplicationControllerSpecTemplateSpecInitContainerStartupProbe[];
    /**
     * volume_mount block.
     */
    readonly volumeMount?: ReplicationControllerSpecTemplateSpecInitContainerVolumeMount[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     */
    readonly user?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecSecurityContextSysctl {
    /**
     * Name of a property to set.
     */
    readonly name: string;
    /**
     * Value of a property to set.
     */
    readonly value: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecSecurityContext {
    /**
     * A special supplemental group that applies to all containers in a pod.
     *
     * Some volume types allow the Kubelet to change the ownership of that volume to be owned by the pod: 1. The owning GID will be the FSGroup 2. The setgid bit is set (new files created in the volume will be owned by FSGroup) 3. The permission bits are OR'd with rw-rw---- If unset, the Kubelet will not modify the ownership and permissions of any volume.
     */
    readonly fsGroup?: number;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.
     */
    readonly runAsGroup?: number;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     */
    readonly runAsNonRoot?: boolean;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.
     */
    readonly runAsUser?: number;
    /**
     * A list of groups applied to the first process run in each container, in addition to the container's primary GID.
     *
     * If unspecified, no groups will be added to any container.
     */
    readonly supplementalGroups?: number[];
    /**
     * se_linux_options block.
     */
    readonly seLinuxOptions?: ReplicationControllerSpecTemplateSpecSecurityContextSeLinuxOptions[];
    /**
     * sysctl block.
     */
    readonly sysctl?: ReplicationControllerSpecTemplateSpecSecurityContextSysctl[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecToleration {
    /**
     * Effect indicates the taint effect to match.
     *
     * Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
     */
    readonly effect?: string;
    /**
     * Key is the taint key that the toleration applies to.
     *
     * Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to the value.
     *
     * Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
     */
    readonly operator?: string;
    /**
     * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint.
     *
     * By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.
     */
    readonly tolerationSeconds?: string;
    /**
     * Value is the taint value the toleration matches to.
     *
     * If the operator is Exists, the value should be empty, otherwise just a regular string.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeAwsElasticBlockStore {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore
     */
    readonly fsType?: string;
    /**
     * The partition in the volume that you want to mount.
     *
     * If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty).
     */
    readonly partition?: number;
    /**
     * Whether to set the read-only property in VolumeMounts to "true".
     *
     * If omitted, the default is "false". More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore
     */
    readonly readOnly?: boolean;
    /**
     * Unique ID of the persistent disk resource in AWS (Amazon EBS volume).
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore
     */
    readonly volumeId: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeAzureDisk {
    /**
     * Host Caching mode: None, Read Only, Read Write.
     */
    readonly cachingMode: string;
    /**
     * The URI the data disk in the blob storage.
     */
    readonly dataDiskUri: string;
    /**
     * The Name of the data disk in the blob storage.
     */
    readonly diskName: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     */
    readonly fsType?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false (read/write).
     */
    readonly readOnly?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeAzureFile {
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false (read/write).
     */
    readonly readOnly?: boolean;
    /**
     * The name of secret that contains Azure Storage Account Name and Key.
     */
    readonly secretName: string;
    /**
     * Share Name.
     */
    readonly shareName: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeCephFsSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeCephFs {
    /**
     * Monitors is a collection of Ceph monitors More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     */
    readonly monitors: string[];
    /**
     * Used as the mounted root, rather than the full Ceph tree, default is /.
     */
    readonly path?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to `false` (read/write). More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it
     */
    readonly readOnly?: boolean;
    /**
     * The path to key ring for User, default is /etc/ceph/user.secret More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     */
    readonly secretFile?: string;
    /**
     * User is the rados user name, default is admin.
     *
     * More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it
     */
    readonly user?: string;
    /**
     * secret_ref block.
     */
    readonly secretRef?: ReplicationControllerSpecTemplateSpecVolumeCephFsSecretRef[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeCinder {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md
     */
    readonly fsType?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false (read/write). More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md
     */
    readonly readOnly?: boolean;
    /**
     * Volume ID used to identify the volume in Cinder.
     *
     * More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md
     */
    readonly volumeId: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeConfigMapItems {
    /**
     * The key to project.
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     */
    readonly path?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeConfigMap {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly defaultMode?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the ConfigMap or its keys must be defined.
     */
    readonly optional?: boolean;
    /**
     * items block.
     */
    readonly items?: ReplicationControllerSpecTemplateSpecVolumeConfigMapItems[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeCsiControllerExpandSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeCsiControllerPublishSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeCsiNodePublishSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeCsiNodeStageSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeCsi {
    /**
     * the name of the volume driver to use.
     *
     * More info: https://kubernetes.io/docs/concepts/storage/volumes/#csi
     */
    readonly driver: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     */
    readonly fsType?: string;
    /**
     * Whether to set the read-only property in VolumeMounts to "true".
     *
     * If omitted, the default is "false". More info: http://kubernetes.io/docs/user-guide/volumes#csi
     */
    readonly readOnly?: boolean;
    /**
     * Attributes of the volume to publish.
     */
    readonly volumeAttributes?: {
        [key: string]: string;
    };
    /**
     * A string value that uniquely identifies the volume.
     *
     * More info: https://kubernetes.io/docs/concepts/storage/volumes/#csi
     */
    readonly volumeHandle: string;
    /**
     * controller_expand_secret_ref block.
     */
    readonly controllerExpandSecretRef?: ReplicationControllerSpecTemplateSpecVolumeCsiControllerExpandSecretRef[];
    /**
     * controller_publish_secret_ref block.
     */
    readonly controllerPublishSecretRef?: ReplicationControllerSpecTemplateSpecVolumeCsiControllerPublishSecretRef[];
    /**
     * node_publish_secret_ref block.
     */
    readonly nodePublishSecretRef?: ReplicationControllerSpecTemplateSpecVolumeCsiNodePublishSecretRef[];
    /**
     * node_stage_secret_ref block.
     */
    readonly nodeStageSecretRef?: ReplicationControllerSpecTemplateSpecVolumeCsiNodeStageSecretRef[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeDownwardApiItemsFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     */
    readonly fieldPath?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef {
    /**
     *
     */
    readonly containerName: string;
    /**
     *
     */
    readonly quantity?: string;
    /**
     * Resource to select.
     */
    readonly resource: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeDownwardApiItems {
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly mode?: string;
    /**
     * Path is the relative path name of the file to be created.
     *
     * Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
     */
    readonly path: string;
    /**
     * field_ref block.
     */
    readonly fieldRef: ReplicationControllerSpecTemplateSpecVolumeDownwardApiItemsFieldRef[];
    /**
     * resource_field_ref block.
     */
    readonly resourceFieldRef?: ReplicationControllerSpecTemplateSpecVolumeDownwardApiItemsResourceFieldRef[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeDownwardApi {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly defaultMode?: string;
    /**
     * items block.
     */
    readonly items?: ReplicationControllerSpecTemplateSpecVolumeDownwardApiItems[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeEmptyDir {
    /**
     * What type of storage medium should back this directory.
     *
     * The default is "" which means to use the node's default medium. Must be an empty string (default) or Memory. More info: http://kubernetes.io/docs/user-guide/volumes#emptydir
     */
    readonly medium?: string;
    /**
     * Total amount of local storage required for this EmptyDir volume.
     */
    readonly sizeLimit?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeFc {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     */
    readonly fsType?: string;
    /**
     * FC target lun number.
     */
    readonly lun: number;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false (read/write).
     */
    readonly readOnly?: boolean;
    /**
     * FC target worldwide names (WWNs).
     */
    readonly targetWwNs: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeFlexVolumeSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeFlexVolume {
    /**
     * Driver is the name of the driver to use for this volume.
     */
    readonly driver: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default filesystem depends on FlexVolume script.
     */
    readonly fsType?: string;
    /**
     * Extra command options if any.
     */
    readonly options?: {
        [key: string]: string;
    };
    /**
     * Whether to force the ReadOnly setting in VolumeMounts.
     *
     * Defaults to false (read/write).
     */
    readonly readOnly?: boolean;
    /**
     * secret_ref block.
     */
    readonly secretRef?: ReplicationControllerSpecTemplateSpecVolumeFlexVolumeSecretRef[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeFlocker {
    /**
     * Name of the dataset stored as metadata -> name on the dataset for Flocker should be considered as deprecated.
     */
    readonly datasetName?: string;
    /**
     * UUID of the dataset.
     *
     * This is unique identifier of a Flocker dataset
     */
    readonly datasetUuid?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeGcePersistentDisk {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     */
    readonly fsType?: string;
    /**
     * The partition in the volume that you want to mount.
     *
     * If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty). More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     */
    readonly partition?: number;
    /**
     * Unique name of the PD resource in GCE.
     *
     * Used to identify the disk in GCE. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     */
    readonly pdName: string;
    /**
     * Whether to force the ReadOnly setting in VolumeMounts.
     *
     * Defaults to false. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     */
    readonly readOnly?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeGitRepo {
    /**
     * Target directory name.
     *
     * Must not contain or start with '..'. If '.' is supplied, the volume directory will be the git repository. Otherwise, if specified, the volume will contain the git repository in the subdirectory with the given name.
     */
    readonly directory?: string;
    /**
     * Repository URL.
     */
    readonly repository?: string;
    /**
     * Commit hash for the specified revision.
     */
    readonly revision?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeGlusterfs {
    /**
     * The endpoint name that details Glusterfs topology.
     *
     * More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod
     */
    readonly endpointsName: string;
    /**
     * The Glusterfs volume path.
     *
     * More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod
     */
    readonly path: string;
    /**
     * Whether to force the Glusterfs volume to be mounted with read-only permissions.
     *
     * Defaults to false. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod
     */
    readonly readOnly?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeHostPath {
    /**
     * Path of the directory on the host.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#hostpath
     */
    readonly path?: string;
    /**
     * Type for HostPath volume.
     *
     * Allowed values are "" (default), DirectoryOrCreate, Directory, FileOrCreate, File, Socket, CharDevice and BlockDevice
     */
    readonly type?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeIscsi {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#iscsi
     */
    readonly fsType?: string;
    /**
     * Target iSCSI Qualified Name.
     */
    readonly iqn: string;
    /**
     * iSCSI interface name that uses an iSCSI transport.
     *
     * Defaults to 'default' (tcp).
     */
    readonly iscsiInterface?: string;
    /**
     * iSCSI target lun number.
     */
    readonly lun?: number;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false.
     */
    readonly readOnly?: boolean;
    /**
     * iSCSI target portal.
     *
     * The portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).
     */
    readonly targetPortal: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeLocal {
    /**
     * Path of the directory on the host.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#local
     */
    readonly path?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeNfs {
    /**
     * Path that is exported by the NFS server.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#nfs
     */
    readonly path: string;
    /**
     * Whether to force the NFS export to be mounted with read-only permissions.
     *
     * Defaults to false. More info: http://kubernetes.io/docs/user-guide/volumes#nfs
     */
    readonly readOnly?: boolean;
    /**
     * Server is the hostname or IP address of the NFS server.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#nfs
     */
    readonly server: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumePersistentVolumeClaim {
    /**
     * ClaimName is the name of a PersistentVolumeClaim in the same.
     */
    readonly claimName?: string;
    /**
     * Will force the ReadOnly setting in VolumeMounts.
     */
    readonly readOnly?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumePhotonPersistentDisk {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     */
    readonly fsType?: string;
    /**
     * ID that identifies Photon Controller persistent disk.
     */
    readonly pdId: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeProjectedSourcesConfigMapItems {
    /**
     * The key to project.
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     */
    readonly path?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeProjectedSourcesConfigMap {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the ConfigMap or it's keys must be defined.
     */
    readonly optional?: boolean;
    /**
     * items block.
     */
    readonly items?: ReplicationControllerSpecTemplateSpecVolumeProjectedSourcesConfigMapItems[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to 'v1'.
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     */
    readonly fieldPath?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef {
    /**
     *
     */
    readonly containerName: string;
    /**
     *
     */
    readonly quantity?: string;
    /**
     * Resource to select.
     */
    readonly resource: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeProjectedSourcesDownwardApiItems {
    /**
     * Mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly mode?: string;
    /**
     * Path is the relative path name of the file to be created.
     *
     * Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
     */
    readonly path: string;
    /**
     * field_ref block.
     */
    readonly fieldRef?: ReplicationControllerSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsFieldRef[];
    /**
     * resource_field_ref block.
     */
    readonly resourceFieldRef?: ReplicationControllerSpecTemplateSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeProjectedSourcesDownwardApi {
    /**
     * items block.
     */
    readonly items?: ReplicationControllerSpecTemplateSpecVolumeProjectedSourcesDownwardApiItems[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeProjectedSourcesSecretItems {
    /**
     * The key to project.
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     */
    readonly path?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeProjectedSourcesSecret {
    /**
     * Name of the secret in the pod's namespace to use.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#secrets
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the Secret or it's keys must be defined.
     */
    readonly optional?: boolean;
    /**
     * items block.
     */
    readonly items?: ReplicationControllerSpecTemplateSpecVolumeProjectedSourcesSecretItems[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeProjectedSourcesServiceAccountToken {
    /**
     * Audience is the intended audience of the token.
     */
    readonly audience?: string;
    /**
     * ExpirationSeconds is the expected duration of validity of the service account token.
     *
     * It defaults to 1 hour and must be at least 10 minutes (600 seconds).
     */
    readonly expirationSeconds?: number;
    /**
     * Path specifies a relative path to the mount point of the projected volume.
     */
    readonly path: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeProjectedSources {
    /**
     * config_map block.
     */
    readonly configMap?: ReplicationControllerSpecTemplateSpecVolumeProjectedSourcesConfigMap[];
    /**
     * downward_api block.
     */
    readonly downwardApi?: ReplicationControllerSpecTemplateSpecVolumeProjectedSourcesDownwardApi[];
    /**
     * secret block.
     */
    readonly secret?: ReplicationControllerSpecTemplateSpecVolumeProjectedSourcesSecret[];
    /**
     * service_account_token block.
     */
    readonly serviceAccountToken?: ReplicationControllerSpecTemplateSpecVolumeProjectedSourcesServiceAccountToken[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeProjected {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly defaultMode?: string;
    /**
     * sources block.
     */
    readonly sources: ReplicationControllerSpecTemplateSpecVolumeProjectedSources[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeQuobyte {
    /**
     * Group to map volume access to Default is no group.
     */
    readonly group?: string;
    /**
     * Whether to force the Quobyte volume to be mounted with read-only permissions.
     *
     * Defaults to false.
     */
    readonly readOnly?: boolean;
    /**
     * Registry represents a single or multiple Quobyte Registry services specified as a string as host:port pair (multiple entries are separated with commas) which acts as the central registry for volumes.
     */
    readonly registry: string;
    /**
     * User to map volume access to Defaults to serivceaccount user.
     */
    readonly user?: string;
    /**
     * Volume is a string that references an already created Quobyte volume by name.
     */
    readonly volume: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeRbdSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeRbd {
    /**
     * A collection of Ceph monitors.
     *
     * More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it
     */
    readonly cephMonitors: string[];
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#rbd
     */
    readonly fsType?: string;
    /**
     * Keyring is the path to key ring for RBDUser.
     *
     * Default is /etc/ceph/keyring. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it
     */
    readonly keyring?: string;
    /**
     * The rados user name.
     *
     * Default is admin. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it
     */
    readonly radosUser?: string;
    /**
     * The rados image name.
     *
     * More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it
     */
    readonly rbdImage: string;
    /**
     * The rados pool name.
     *
     * Default is rbd. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     */
    readonly rbdPool?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it
     */
    readonly readOnly?: boolean;
    /**
     * secret_ref block.
     */
    readonly secretRef?: ReplicationControllerSpecTemplateSpecVolumeRbdSecretRef[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeSecretItems {
    /**
     * The key to project.
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     */
    readonly path?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeSecret {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly defaultMode?: string;
    /**
     * Optional: Specify whether the Secret or its keys must be defined.
     */
    readonly optional?: boolean;
    /**
     * Name of the secret in the pod's namespace to use.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#secrets
     */
    readonly secretName?: string;
    /**
     * items block.
     */
    readonly items?: ReplicationControllerSpecTemplateSpecVolumeSecretItems[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolumeVsphereVolume {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     */
    readonly fsType?: string;
    /**
     * Path that identifies vSphere volume vmdk.
     */
    readonly volumePath: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpecVolume {
    /**
     * Volume's name.
     *
     * Must be a DNS_LABEL and unique within the pod. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * aws_elastic_block_store block.
     */
    readonly awsElasticBlockStore?: ReplicationControllerSpecTemplateSpecVolumeAwsElasticBlockStore[];
    /**
     * azure_disk block.
     */
    readonly azureDisk?: ReplicationControllerSpecTemplateSpecVolumeAzureDisk[];
    /**
     * azure_file block.
     */
    readonly azureFile?: ReplicationControllerSpecTemplateSpecVolumeAzureFile[];
    /**
     * ceph_fs block.
     */
    readonly cephFs?: ReplicationControllerSpecTemplateSpecVolumeCephFs[];
    /**
     * cinder block.
     */
    readonly cinder?: ReplicationControllerSpecTemplateSpecVolumeCinder[];
    /**
     * config_map block.
     */
    readonly configMap?: ReplicationControllerSpecTemplateSpecVolumeConfigMap[];
    /**
     * csi block.
     */
    readonly csi?: ReplicationControllerSpecTemplateSpecVolumeCsi[];
    /**
     * downward_api block.
     */
    readonly downwardApi?: ReplicationControllerSpecTemplateSpecVolumeDownwardApi[];
    /**
     * empty_dir block.
     */
    readonly emptyDir?: ReplicationControllerSpecTemplateSpecVolumeEmptyDir[];
    /**
     * fc block.
     */
    readonly fc?: ReplicationControllerSpecTemplateSpecVolumeFc[];
    /**
     * flex_volume block.
     */
    readonly flexVolume?: ReplicationControllerSpecTemplateSpecVolumeFlexVolume[];
    /**
     * flocker block.
     */
    readonly flocker?: ReplicationControllerSpecTemplateSpecVolumeFlocker[];
    /**
     * gce_persistent_disk block.
     */
    readonly gcePersistentDisk?: ReplicationControllerSpecTemplateSpecVolumeGcePersistentDisk[];
    /**
     * git_repo block.
     */
    readonly gitRepo?: ReplicationControllerSpecTemplateSpecVolumeGitRepo[];
    /**
     * glusterfs block.
     */
    readonly glusterfs?: ReplicationControllerSpecTemplateSpecVolumeGlusterfs[];
    /**
     * host_path block.
     */
    readonly hostPath?: ReplicationControllerSpecTemplateSpecVolumeHostPath[];
    /**
     * iscsi block.
     */
    readonly iscsi?: ReplicationControllerSpecTemplateSpecVolumeIscsi[];
    /**
     * local block.
     */
    readonly local?: ReplicationControllerSpecTemplateSpecVolumeLocal[];
    /**
     * nfs block.
     */
    readonly nfs?: ReplicationControllerSpecTemplateSpecVolumeNfs[];
    /**
     * persistent_volume_claim block.
     */
    readonly persistentVolumeClaim?: ReplicationControllerSpecTemplateSpecVolumePersistentVolumeClaim[];
    /**
     * photon_persistent_disk block.
     */
    readonly photonPersistentDisk?: ReplicationControllerSpecTemplateSpecVolumePhotonPersistentDisk[];
    /**
     * projected block.
     */
    readonly projected?: ReplicationControllerSpecTemplateSpecVolumeProjected[];
    /**
     * quobyte block.
     */
    readonly quobyte?: ReplicationControllerSpecTemplateSpecVolumeQuobyte[];
    /**
     * rbd block.
     */
    readonly rbd?: ReplicationControllerSpecTemplateSpecVolumeRbd[];
    /**
     * secret block.
     */
    readonly secret?: ReplicationControllerSpecTemplateSpecVolumeSecret[];
    /**
     * vsphere_volume block.
     */
    readonly vsphereVolume?: ReplicationControllerSpecTemplateSpecVolumeVsphereVolume[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateSpec {
    /**
     * Optional duration in seconds the pod may be active on the node relative to StartTime before the system will actively try to mark it failed and kill associated containers.
     *
     * Value must be a positive integer.
     */
    readonly activeDeadlineSeconds?: number;
    /**
     * AutomountServiceAccountToken indicates whether a service account token should be automatically mounted.
     */
    readonly automountServiceAccountToken?: boolean;
    /**
     * Set DNS policy for containers within the pod.
     *
     * Valid values are 'ClusterFirstWithHostNet', 'ClusterFirst', 'Default' or 'None'. DNS parameters given in DNSConfig will be merged with the policy selected with DNSPolicy. To have DNS options set along with hostNetwork, you have to specify DNS policy explicitly to 'ClusterFirstWithHostNet'. Optional: Defaults to 'ClusterFirst', see [Kubernetes reference](https://kubernetes.io/docs/concepts/services-networking/dns-pod-service/#pod-s-dns-policy).
     */
    readonly dnsPolicy?: string;
    /**
     * Use the host's ipc namespace.
     *
     * Optional: Defaults to false.
     */
    readonly hostIpc?: boolean;
    /**
     * Host networking requested for this pod.
     *
     * Use the host's network namespace. If this option is set, the ports that will be used must be specified.
     */
    readonly hostNetwork?: boolean;
    /**
     * Use the host's pid namespace.
     */
    readonly hostPid?: boolean;
    /**
     * Specifies the hostname of the Pod If not specified, the pod's hostname will be set to a system-defined value.
     */
    readonly hostname?: string;
    /**
     * NodeName is a request to schedule this pod onto a specific node.
     *
     * If it is non-empty, the scheduler simply schedules this pod onto that node, assuming that it fits resource requirements.
     */
    readonly nodeName?: string;
    /**
     * NodeSelector is a selector which must be true for the pod to fit on a node.
     *
     * Selector which must match a node's labels for the pod to be scheduled on that node. More info: http://kubernetes.io/docs/user-guide/node-selection.
     */
    readonly nodeSelector?: {
        [key: string]: string;
    };
    /**
     * If specified, indicates the pod's priority.
     *
     * "system-node-critical" and "system-cluster-critical" are two special keywords which indicate the highest priorities with the former being the highest priority. Any other name must be defined by creating a PriorityClass object with that name. If not specified, the pod priority will be default or zero if there is no default.
     */
    readonly priorityClassName?: string;
    /**
     * Restart policy for all containers within the pod.
     *
     * One of Always, OnFailure, Never. More info: http://kubernetes.io/docs/user-guide/pod-states#restartpolicy.
     */
    readonly restartPolicy?: string;
    /**
     * ServiceAccountName is the name of the ServiceAccount to use to run this pod.
     *
     * More info: http://releases.k8s.io/HEAD/docs/design/service_accounts.md.
     */
    readonly serviceAccountName?: string;
    /**
     * Share a single process namespace between all of the containers in a pod.
     *
     * When this is set containers will be able to view and signal processes from other containers in the same pod, and the first process in each container will not be assigned PID 1. HostPID and ShareProcessNamespace cannot both be set. Optional: Defaults to false.
     */
    readonly shareProcessNamespace?: boolean;
    /**
     * If specified, the fully qualified Pod hostname will be "...svc.". If not specified, the pod will not have a domainname at all..
     */
    readonly subdomain?: string;
    /**
     * Optional duration in seconds the pod needs to terminate gracefully.
     *
     * May be decreased in delete request. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period will be used instead. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process.
     */
    readonly terminationGracePeriodSeconds?: number;
    /**
     * affinity block.
     */
    readonly affinity?: ReplicationControllerSpecTemplateSpecAffinity[];
    /**
     * container block.
     */
    readonly container?: ReplicationControllerSpecTemplateSpecContainer[];
    /**
     * dns_config block.
     */
    readonly dnsConfig?: ReplicationControllerSpecTemplateSpecDnsConfig[];
    /**
     * host_aliases block.
     */
    readonly hostAliases?: ReplicationControllerSpecTemplateSpecHostAliases[];
    /**
     * image_pull_secrets block.
     */
    readonly imagePullSecrets?: ReplicationControllerSpecTemplateSpecImagePullSecrets[];
    /**
     * init_container block.
     */
    readonly initContainer?: ReplicationControllerSpecTemplateSpecInitContainer[];
    /**
     * security_context block.
     */
    readonly securityContext?: ReplicationControllerSpecTemplateSpecSecurityContext[];
    /**
     * toleration block.
     */
    readonly toleration?: ReplicationControllerSpecTemplateSpecToleration[];
    /**
     * volume block.
     */
    readonly volume?: ReplicationControllerSpecTemplateSpecVolume[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateToleration {
    /**
     * Effect indicates the taint effect to match.
     *
     * Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
     */
    readonly effect?: string;
    /**
     * Key is the taint key that the toleration applies to.
     *
     * Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to the value.
     *
     * Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
     */
    readonly operator?: string;
    /**
     * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint.
     *
     * By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.
     */
    readonly tolerationSeconds?: string;
    /**
     * Value is the taint value the toleration matches to.
     *
     * If the operator is Exists, the value should be empty, otherwise just a regular string.
     */
    readonly value?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeAwsElasticBlockStore {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore
     */
    readonly fsType?: string;
    /**
     * The partition in the volume that you want to mount.
     *
     * If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty).
     */
    readonly partition?: number;
    /**
     * Whether to set the read-only property in VolumeMounts to "true".
     *
     * If omitted, the default is "false". More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore
     */
    readonly readOnly?: boolean;
    /**
     * Unique ID of the persistent disk resource in AWS (Amazon EBS volume).
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore
     */
    readonly volumeId: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeAzureDisk {
    /**
     * Host Caching mode: None, Read Only, Read Write.
     */
    readonly cachingMode: string;
    /**
     * The URI the data disk in the blob storage.
     */
    readonly dataDiskUri: string;
    /**
     * The Name of the data disk in the blob storage.
     */
    readonly diskName: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     */
    readonly fsType?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false (read/write).
     */
    readonly readOnly?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeAzureFile {
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false (read/write).
     */
    readonly readOnly?: boolean;
    /**
     * The name of secret that contains Azure Storage Account Name and Key.
     */
    readonly secretName: string;
    /**
     * Share Name.
     */
    readonly shareName: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeCephFsSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeCephFs {
    /**
     * Monitors is a collection of Ceph monitors More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     */
    readonly monitors: string[];
    /**
     * Used as the mounted root, rather than the full Ceph tree, default is /.
     */
    readonly path?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to `false` (read/write). More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it
     */
    readonly readOnly?: boolean;
    /**
     * The path to key ring for User, default is /etc/ceph/user.secret More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     */
    readonly secretFile?: string;
    /**
     * User is the rados user name, default is admin.
     *
     * More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it
     */
    readonly user?: string;
    /**
     * secret_ref block.
     */
    readonly secretRef?: ReplicationControllerSpecTemplateVolumeCephFsSecretRef[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeCinder {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md
     */
    readonly fsType?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false (read/write). More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md
     */
    readonly readOnly?: boolean;
    /**
     * Volume ID used to identify the volume in Cinder.
     *
     * More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md
     */
    readonly volumeId: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeConfigMapItems {
    /**
     * The key to project.
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     */
    readonly path?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeConfigMap {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly defaultMode?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the ConfigMap or its keys must be defined.
     */
    readonly optional?: boolean;
    /**
     * items block.
     */
    readonly items?: ReplicationControllerSpecTemplateVolumeConfigMapItems[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeCsiControllerExpandSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeCsiControllerPublishSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeCsiNodePublishSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeCsiNodeStageSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeCsi {
    /**
     * the name of the volume driver to use.
     *
     * More info: https://kubernetes.io/docs/concepts/storage/volumes/#csi
     */
    readonly driver: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     */
    readonly fsType?: string;
    /**
     * Whether to set the read-only property in VolumeMounts to "true".
     *
     * If omitted, the default is "false". More info: http://kubernetes.io/docs/user-guide/volumes#csi
     */
    readonly readOnly?: boolean;
    /**
     * Attributes of the volume to publish.
     */
    readonly volumeAttributes?: {
        [key: string]: string;
    };
    /**
     * A string value that uniquely identifies the volume.
     *
     * More info: https://kubernetes.io/docs/concepts/storage/volumes/#csi
     */
    readonly volumeHandle: string;
    /**
     * controller_expand_secret_ref block.
     */
    readonly controllerExpandSecretRef?: ReplicationControllerSpecTemplateVolumeCsiControllerExpandSecretRef[];
    /**
     * controller_publish_secret_ref block.
     */
    readonly controllerPublishSecretRef?: ReplicationControllerSpecTemplateVolumeCsiControllerPublishSecretRef[];
    /**
     * node_publish_secret_ref block.
     */
    readonly nodePublishSecretRef?: ReplicationControllerSpecTemplateVolumeCsiNodePublishSecretRef[];
    /**
     * node_stage_secret_ref block.
     */
    readonly nodeStageSecretRef?: ReplicationControllerSpecTemplateVolumeCsiNodeStageSecretRef[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeDownwardApiItemsFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     */
    readonly fieldPath?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeDownwardApiItemsResourceFieldRef {
    /**
     *
     */
    readonly containerName: string;
    /**
     *
     */
    readonly quantity?: string;
    /**
     * Resource to select.
     */
    readonly resource: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeDownwardApiItems {
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly mode?: string;
    /**
     * Path is the relative path name of the file to be created.
     *
     * Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
     */
    readonly path: string;
    /**
     * field_ref block.
     */
    readonly fieldRef: ReplicationControllerSpecTemplateVolumeDownwardApiItemsFieldRef[];
    /**
     * resource_field_ref block.
     */
    readonly resourceFieldRef?: ReplicationControllerSpecTemplateVolumeDownwardApiItemsResourceFieldRef[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeDownwardApi {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly defaultMode?: string;
    /**
     * items block.
     */
    readonly items?: ReplicationControllerSpecTemplateVolumeDownwardApiItems[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeEmptyDir {
    /**
     * What type of storage medium should back this directory.
     *
     * The default is "" which means to use the node's default medium. Must be an empty string (default) or Memory. More info: http://kubernetes.io/docs/user-guide/volumes#emptydir
     */
    readonly medium?: string;
    /**
     * Total amount of local storage required for this EmptyDir volume.
     */
    readonly sizeLimit?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeFc {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     */
    readonly fsType?: string;
    /**
     * FC target lun number.
     */
    readonly lun: number;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false (read/write).
     */
    readonly readOnly?: boolean;
    /**
     * FC target worldwide names (WWNs).
     */
    readonly targetWwNs: string[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeFlexVolumeSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeFlexVolume {
    /**
     * Driver is the name of the driver to use for this volume.
     */
    readonly driver: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default filesystem depends on FlexVolume script.
     */
    readonly fsType?: string;
    /**
     * Extra command options if any.
     */
    readonly options?: {
        [key: string]: string;
    };
    /**
     * Whether to force the ReadOnly setting in VolumeMounts.
     *
     * Defaults to false (read/write).
     */
    readonly readOnly?: boolean;
    /**
     * secret_ref block.
     */
    readonly secretRef?: ReplicationControllerSpecTemplateVolumeFlexVolumeSecretRef[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeFlocker {
    /**
     * Name of the dataset stored as metadata -> name on the dataset for Flocker should be considered as deprecated.
     */
    readonly datasetName?: string;
    /**
     * UUID of the dataset.
     *
     * This is unique identifier of a Flocker dataset
     */
    readonly datasetUuid?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeGcePersistentDisk {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     */
    readonly fsType?: string;
    /**
     * The partition in the volume that you want to mount.
     *
     * If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty). More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     */
    readonly partition?: number;
    /**
     * Unique name of the PD resource in GCE.
     *
     * Used to identify the disk in GCE. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     */
    readonly pdName: string;
    /**
     * Whether to force the ReadOnly setting in VolumeMounts.
     *
     * Defaults to false. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     */
    readonly readOnly?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeGitRepo {
    /**
     * Target directory name.
     *
     * Must not contain or start with '..'. If '.' is supplied, the volume directory will be the git repository. Otherwise, if specified, the volume will contain the git repository in the subdirectory with the given name.
     */
    readonly directory?: string;
    /**
     * Repository URL.
     */
    readonly repository?: string;
    /**
     * Commit hash for the specified revision.
     */
    readonly revision?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeGlusterfs {
    /**
     * The endpoint name that details Glusterfs topology.
     *
     * More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod
     */
    readonly endpointsName: string;
    /**
     * The Glusterfs volume path.
     *
     * More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod
     */
    readonly path: string;
    /**
     * Whether to force the Glusterfs volume to be mounted with read-only permissions.
     *
     * Defaults to false. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod
     */
    readonly readOnly?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeHostPath {
    /**
     * Path of the directory on the host.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#hostpath
     */
    readonly path?: string;
    /**
     * Type for HostPath volume.
     *
     * Allowed values are "" (default), DirectoryOrCreate, Directory, FileOrCreate, File, Socket, CharDevice and BlockDevice
     */
    readonly type?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeIscsi {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#iscsi
     */
    readonly fsType?: string;
    /**
     * Target iSCSI Qualified Name.
     */
    readonly iqn: string;
    /**
     * iSCSI interface name that uses an iSCSI transport.
     *
     * Defaults to 'default' (tcp).
     */
    readonly iscsiInterface?: string;
    /**
     * iSCSI target lun number.
     */
    readonly lun?: number;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false.
     */
    readonly readOnly?: boolean;
    /**
     * iSCSI target portal.
     *
     * The portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).
     */
    readonly targetPortal: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeLocal {
    /**
     * Path of the directory on the host.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#local
     */
    readonly path?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeNfs {
    /**
     * Path that is exported by the NFS server.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#nfs
     */
    readonly path: string;
    /**
     * Whether to force the NFS export to be mounted with read-only permissions.
     *
     * Defaults to false. More info: http://kubernetes.io/docs/user-guide/volumes#nfs
     */
    readonly readOnly?: boolean;
    /**
     * Server is the hostname or IP address of the NFS server.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#nfs
     */
    readonly server: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumePersistentVolumeClaim {
    /**
     * ClaimName is the name of a PersistentVolumeClaim in the same.
     */
    readonly claimName?: string;
    /**
     * Will force the ReadOnly setting in VolumeMounts.
     */
    readonly readOnly?: boolean;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumePhotonPersistentDisk {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     */
    readonly fsType?: string;
    /**
     * ID that identifies Photon Controller persistent disk.
     */
    readonly pdId: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeProjectedSourcesConfigMapItems {
    /**
     * The key to project.
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     */
    readonly path?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeProjectedSourcesConfigMap {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the ConfigMap or it's keys must be defined.
     */
    readonly optional?: boolean;
    /**
     * items block.
     */
    readonly items?: ReplicationControllerSpecTemplateVolumeProjectedSourcesConfigMapItems[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeProjectedSourcesDownwardApiItemsFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to 'v1'.
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     */
    readonly fieldPath?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeProjectedSourcesDownwardApiItemsResourceFieldRef {
    /**
     *
     */
    readonly containerName: string;
    /**
     *
     */
    readonly quantity?: string;
    /**
     * Resource to select.
     */
    readonly resource: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeProjectedSourcesDownwardApiItems {
    /**
     * Mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly mode?: string;
    /**
     * Path is the relative path name of the file to be created.
     *
     * Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
     */
    readonly path: string;
    /**
     * field_ref block.
     */
    readonly fieldRef?: ReplicationControllerSpecTemplateVolumeProjectedSourcesDownwardApiItemsFieldRef[];
    /**
     * resource_field_ref block.
     */
    readonly resourceFieldRef?: ReplicationControllerSpecTemplateVolumeProjectedSourcesDownwardApiItemsResourceFieldRef[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeProjectedSourcesDownwardApi {
    /**
     * items block.
     */
    readonly items?: ReplicationControllerSpecTemplateVolumeProjectedSourcesDownwardApiItems[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeProjectedSourcesSecretItems {
    /**
     * The key to project.
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     */
    readonly path?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeProjectedSourcesSecret {
    /**
     * Name of the secret in the pod's namespace to use.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#secrets
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the Secret or it's keys must be defined.
     */
    readonly optional?: boolean;
    /**
     * items block.
     */
    readonly items?: ReplicationControllerSpecTemplateVolumeProjectedSourcesSecretItems[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeProjectedSourcesServiceAccountToken {
    /**
     * Audience is the intended audience of the token.
     */
    readonly audience?: string;
    /**
     * ExpirationSeconds is the expected duration of validity of the service account token.
     *
     * It defaults to 1 hour and must be at least 10 minutes (600 seconds).
     */
    readonly expirationSeconds?: number;
    /**
     * Path specifies a relative path to the mount point of the projected volume.
     */
    readonly path: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeProjectedSources {
    /**
     * config_map block.
     */
    readonly configMap?: ReplicationControllerSpecTemplateVolumeProjectedSourcesConfigMap[];
    /**
     * downward_api block.
     */
    readonly downwardApi?: ReplicationControllerSpecTemplateVolumeProjectedSourcesDownwardApi[];
    /**
     * secret block.
     */
    readonly secret?: ReplicationControllerSpecTemplateVolumeProjectedSourcesSecret[];
    /**
     * service_account_token block.
     */
    readonly serviceAccountToken?: ReplicationControllerSpecTemplateVolumeProjectedSourcesServiceAccountToken[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeProjected {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly defaultMode?: string;
    /**
     * sources block.
     */
    readonly sources: ReplicationControllerSpecTemplateVolumeProjectedSources[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeQuobyte {
    /**
     * Group to map volume access to Default is no group.
     */
    readonly group?: string;
    /**
     * Whether to force the Quobyte volume to be mounted with read-only permissions.
     *
     * Defaults to false.
     */
    readonly readOnly?: boolean;
    /**
     * Registry represents a single or multiple Quobyte Registry services specified as a string as host:port pair (multiple entries are separated with commas) which acts as the central registry for volumes.
     */
    readonly registry: string;
    /**
     * User to map volume access to Defaults to serivceaccount user.
     */
    readonly user?: string;
    /**
     * Volume is a string that references an already created Quobyte volume by name.
     */
    readonly volume: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeRbdSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeRbd {
    /**
     * A collection of Ceph monitors.
     *
     * More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it
     */
    readonly cephMonitors: string[];
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#rbd
     */
    readonly fsType?: string;
    /**
     * Keyring is the path to key ring for RBDUser.
     *
     * Default is /etc/ceph/keyring. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it
     */
    readonly keyring?: string;
    /**
     * The rados user name.
     *
     * Default is admin. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it
     */
    readonly radosUser?: string;
    /**
     * The rados image name.
     *
     * More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it
     */
    readonly rbdImage: string;
    /**
     * The rados pool name.
     *
     * Default is rbd. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     */
    readonly rbdPool?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it
     */
    readonly readOnly?: boolean;
    /**
     * secret_ref block.
     */
    readonly secretRef?: ReplicationControllerSpecTemplateVolumeRbdSecretRef[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeSecretItems {
    /**
     * The key to project.
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     */
    readonly path?: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeSecret {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    readonly defaultMode?: string;
    /**
     * Optional: Specify whether the Secret or its keys must be defined.
     */
    readonly optional?: boolean;
    /**
     * Name of the secret in the pod's namespace to use.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#secrets
     */
    readonly secretName?: string;
    /**
     * items block.
     */
    readonly items?: ReplicationControllerSpecTemplateVolumeSecretItems[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolumeVsphereVolume {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     */
    readonly fsType?: string;
    /**
     * Path that identifies vSphere volume vmdk.
     */
    readonly volumePath: string;
}
/**
 *
 */
export interface ReplicationControllerSpecTemplateVolume {
    /**
     * Volume's name.
     *
     * Must be a DNS_LABEL and unique within the pod. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * aws_elastic_block_store block.
     */
    readonly awsElasticBlockStore?: ReplicationControllerSpecTemplateVolumeAwsElasticBlockStore[];
    /**
     * azure_disk block.
     */
    readonly azureDisk?: ReplicationControllerSpecTemplateVolumeAzureDisk[];
    /**
     * azure_file block.
     */
    readonly azureFile?: ReplicationControllerSpecTemplateVolumeAzureFile[];
    /**
     * ceph_fs block.
     */
    readonly cephFs?: ReplicationControllerSpecTemplateVolumeCephFs[];
    /**
     * cinder block.
     */
    readonly cinder?: ReplicationControllerSpecTemplateVolumeCinder[];
    /**
     * config_map block.
     */
    readonly configMap?: ReplicationControllerSpecTemplateVolumeConfigMap[];
    /**
     * csi block.
     */
    readonly csi?: ReplicationControllerSpecTemplateVolumeCsi[];
    /**
     * downward_api block.
     */
    readonly downwardApi?: ReplicationControllerSpecTemplateVolumeDownwardApi[];
    /**
     * empty_dir block.
     */
    readonly emptyDir?: ReplicationControllerSpecTemplateVolumeEmptyDir[];
    /**
     * fc block.
     */
    readonly fc?: ReplicationControllerSpecTemplateVolumeFc[];
    /**
     * flex_volume block.
     */
    readonly flexVolume?: ReplicationControllerSpecTemplateVolumeFlexVolume[];
    /**
     * flocker block.
     */
    readonly flocker?: ReplicationControllerSpecTemplateVolumeFlocker[];
    /**
     * gce_persistent_disk block.
     */
    readonly gcePersistentDisk?: ReplicationControllerSpecTemplateVolumeGcePersistentDisk[];
    /**
     * git_repo block.
     */
    readonly gitRepo?: ReplicationControllerSpecTemplateVolumeGitRepo[];
    /**
     * glusterfs block.
     */
    readonly glusterfs?: ReplicationControllerSpecTemplateVolumeGlusterfs[];
    /**
     * host_path block.
     */
    readonly hostPath?: ReplicationControllerSpecTemplateVolumeHostPath[];
    /**
     * iscsi block.
     */
    readonly iscsi?: ReplicationControllerSpecTemplateVolumeIscsi[];
    /**
     * local block.
     */
    readonly local?: ReplicationControllerSpecTemplateVolumeLocal[];
    /**
     * nfs block.
     */
    readonly nfs?: ReplicationControllerSpecTemplateVolumeNfs[];
    /**
     * persistent_volume_claim block.
     */
    readonly persistentVolumeClaim?: ReplicationControllerSpecTemplateVolumePersistentVolumeClaim[];
    /**
     * photon_persistent_disk block.
     */
    readonly photonPersistentDisk?: ReplicationControllerSpecTemplateVolumePhotonPersistentDisk[];
    /**
     * projected block.
     */
    readonly projected?: ReplicationControllerSpecTemplateVolumeProjected[];
    /**
     * quobyte block.
     */
    readonly quobyte?: ReplicationControllerSpecTemplateVolumeQuobyte[];
    /**
     * rbd block.
     */
    readonly rbd?: ReplicationControllerSpecTemplateVolumeRbd[];
    /**
     * secret block.
     */
    readonly secret?: ReplicationControllerSpecTemplateVolumeSecret[];
    /**
     * vsphere_volume block.
     */
    readonly vsphereVolume?: ReplicationControllerSpecTemplateVolumeVsphereVolume[];
}
/**
 *
 */
export interface ReplicationControllerSpecTemplate {
    /**
     * Optional duration in seconds the pod may be active on the node relative to StartTime before the system will actively try to mark it failed and kill associated containers.
     *
     * Value must be a positive integer.
     */
    readonly activeDeadlineSeconds?: number;
    /**
     * AutomountServiceAccountToken indicates whether a service account token should be automatically mounted.
     */
    readonly automountServiceAccountToken?: boolean;
    /**
     * Set DNS policy for containers within the pod.
     *
     * Valid values are 'ClusterFirstWithHostNet', 'ClusterFirst', 'Default' or 'None'. DNS parameters given in DNSConfig will be merged with the policy selected with DNSPolicy. To have DNS options set along with hostNetwork, you have to specify DNS policy explicitly to 'ClusterFirstWithHostNet'. Optional: Defaults to 'ClusterFirst', see [Kubernetes reference](https://kubernetes.io/docs/concepts/services-networking/dns-pod-service/#pod-s-dns-policy).
     */
    readonly dnsPolicy?: string;
    /**
     * Use the host's ipc namespace.
     *
     * Optional: Defaults to false.
     */
    readonly hostIpc?: boolean;
    /**
     * Host networking requested for this pod.
     *
     * Use the host's network namespace. If this option is set, the ports that will be used must be specified.
     */
    readonly hostNetwork?: boolean;
    /**
     * Use the host's pid namespace.
     */
    readonly hostPid?: boolean;
    /**
     * Specifies the hostname of the Pod If not specified, the pod's hostname will be set to a system-defined value.
     */
    readonly hostname?: string;
    /**
     * NodeName is a request to schedule this pod onto a specific node.
     *
     * If it is non-empty, the scheduler simply schedules this pod onto that node, assuming that it fits resource requirements.
     */
    readonly nodeName?: string;
    /**
     * NodeSelector is a selector which must be true for the pod to fit on a node.
     *
     * Selector which must match a node's labels for the pod to be scheduled on that node. More info: http://kubernetes.io/docs/user-guide/node-selection.
     */
    readonly nodeSelector?: {
        [key: string]: string;
    };
    /**
     * If specified, indicates the pod's priority.
     *
     * "system-node-critical" and "system-cluster-critical" are two special keywords which indicate the highest priorities with the former being the highest priority. Any other name must be defined by creating a PriorityClass object with that name. If not specified, the pod priority will be default or zero if there is no default.
     */
    readonly priorityClassName?: string;
    /**
     * Restart policy for all containers within the pod.
     *
     * One of Always, OnFailure, Never. More info: http://kubernetes.io/docs/user-guide/pod-states#restartpolicy.
     */
    readonly restartPolicy?: string;
    /**
     * ServiceAccountName is the name of the ServiceAccount to use to run this pod.
     *
     * More info: http://releases.k8s.io/HEAD/docs/design/service_accounts.md.
     */
    readonly serviceAccountName?: string;
    /**
     * Share a single process namespace between all of the containers in a pod.
     *
     * When this is set containers will be able to view and signal processes from other containers in the same pod, and the first process in each container will not be assigned PID 1. HostPID and ShareProcessNamespace cannot both be set. Optional: Defaults to false.
     */
    readonly shareProcessNamespace?: boolean;
    /**
     * If specified, the fully qualified Pod hostname will be "...svc.". If not specified, the pod will not have a domainname at all..
     */
    readonly subdomain?: string;
    /**
     * Optional duration in seconds the pod needs to terminate gracefully.
     *
     * May be decreased in delete request. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period will be used instead. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process.
     */
    readonly terminationGracePeriodSeconds?: number;
    /**
     * affinity block.
     */
    readonly affinity?: ReplicationControllerSpecTemplateAffinity[];
    /**
     * container block.
     */
    readonly container?: ReplicationControllerSpecTemplateContainer[];
    /**
     * dns_config block.
     */
    readonly dnsConfig?: ReplicationControllerSpecTemplateDnsConfig[];
    /**
     * host_aliases block.
     */
    readonly hostAliases?: ReplicationControllerSpecTemplateHostAliases[];
    /**
     * image_pull_secrets block.
     */
    readonly imagePullSecrets?: ReplicationControllerSpecTemplateImagePullSecrets[];
    /**
     * init_container block.
     */
    readonly initContainer?: ReplicationControllerSpecTemplateInitContainer[];
    /**
     * metadata block.
     */
    readonly metadata?: ReplicationControllerSpecTemplateMetadata[];
    /**
     * security_context block.
     */
    readonly securityContext?: ReplicationControllerSpecTemplateSecurityContext[];
    /**
     * spec block.
     */
    readonly spec?: ReplicationControllerSpecTemplateSpec[];
    /**
     * toleration block.
     */
    readonly toleration?: ReplicationControllerSpecTemplateToleration[];
    /**
     * volume block.
     */
    readonly volume?: ReplicationControllerSpecTemplateVolume[];
}
/**
 *
 */
export interface ReplicationControllerSpec {
    /**
     * Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available.
     *
     * Defaults to 0 (pod will be considered available as soon as it is ready)
     */
    readonly minReadySeconds?: number;
    /**
     * The number of desired replicas.
     *
     * Defaults to 1. More info: http://kubernetes.io/docs/user-guide/replication-controller#what-is-a-replication-controller
     */
    readonly replicas?: number;
    /**
     * A label query over pods that should match the Replicas count.
     *
     * If Selector is empty, it is defaulted to the labels present on the Pod template. Label keys and values that must match in order to be controlled by this replication controller, if empty defaulted to labels on Pod template. More info: http://kubernetes.io/docs/user-guide/labels#label-selectors
     */
    readonly selector: {
        [key: string]: string;
    };
    /**
     * template block.
     */
    readonly template: ReplicationControllerSpecTemplate[];
}
/**
 *
 */
export interface ReplicationControllerTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
    /**
     *
     */
    readonly update?: string;
}
/**
 *
 */
export declare class ReplicationController extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ReplicationControllerConfig);
    private _id?;
    /**
     *
     */
    get id(): string | undefined;
    /**
     *
     */
    set id(value: string | undefined);
    private _metadata;
    /**
     *
     */
    get metadata(): ReplicationControllerMetadata[];
    /**
     *
     */
    set metadata(value: ReplicationControllerMetadata[]);
    private _spec;
    /**
     *
     */
    get spec(): ReplicationControllerSpec[];
    /**
     *
     */
    set spec(value: ReplicationControllerSpec[]);
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ReplicationControllerTimeouts | undefined;
    /**
     *
     */
    set timeouts(value: ReplicationControllerTimeouts | undefined);
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
